[Libreoffice-commits] core.git: sc/source
Christian M. Heller
christian.heller63 at gmail.com
Wed Jan 14 02:25:20 PST 2015
sc/source/core/data/column.cxx | 10 +-
sc/source/core/data/column2.cxx | 14 ++--
sc/source/core/data/column3.cxx | 4 -
sc/source/core/data/conditio.cxx | 8 +-
sc/source/core/data/dbdocutl.cxx | 6 -
sc/source/core/data/documen3.cxx | 6 -
sc/source/core/data/documen4.cxx | 8 +-
sc/source/core/data/documen5.cxx | 2
sc/source/core/data/documen7.cxx | 4 -
sc/source/core/data/documen8.cxx | 4 -
sc/source/core/data/documen9.cxx | 4 -
sc/source/core/data/document.cxx | 6 -
sc/source/core/data/dpdimsave.cxx | 18 ++---
sc/source/core/data/dpgroup.cxx | 4 -
sc/source/core/data/dpobject.cxx | 34 ++++-----
sc/source/core/data/dpoutput.cxx | 60 ++++++++---------
sc/source/core/data/dpsave.cxx | 12 +--
sc/source/core/data/dpsdbtab.cxx | 8 +-
sc/source/core/data/dpshttab.cxx | 2
sc/source/core/data/dptabdat.cxx | 8 +-
sc/source/core/data/dptabres.cxx | 52 +++++++--------
sc/source/core/data/dptabsrc.cxx | 120 +++++++++++++++++------------------
sc/source/core/data/dputil.cxx | 2
sc/source/core/data/drwlayer.cxx | 16 ++--
sc/source/core/data/fillinfo.cxx | 12 +--
sc/source/core/data/formulacell.cxx | 4 -
sc/source/core/data/global.cxx | 4 -
sc/source/core/data/global2.cxx | 2
sc/source/core/data/markdata.cxx | 16 ++--
sc/source/core/data/patattr.cxx | 10 +-
sc/source/core/data/sortparam.cxx | 2
sc/source/core/data/stlpool.cxx | 2
sc/source/core/data/stlsheet.cxx | 13 +--
sc/source/core/data/table1.cxx | 16 ++--
sc/source/core/data/table2.cxx | 14 ++--
sc/source/core/data/table3.cxx | 8 +-
sc/source/core/data/table4.cxx | 4 -
sc/source/core/data/table6.cxx | 2
sc/source/core/data/validat.cxx | 16 ++--
sc/source/core/tool/addincol.cxx | 50 +++++++-------
sc/source/core/tool/addinlis.cxx | 4 -
sc/source/core/tool/appoptio.cxx | 2
sc/source/core/tool/charthelper.cxx | 2
sc/source/core/tool/chgtrack.cxx | 60 ++++++++---------
sc/source/core/tool/compiler.cxx | 6 -
sc/source/core/tool/consoli.cxx | 16 ++--
sc/source/core/tool/dbdata.cxx | 2
sc/source/core/tool/ddelink.cxx | 2
sc/source/core/tool/detfunc.cxx | 16 ++--
sc/source/core/tool/editutil.cxx | 4 -
sc/source/core/tool/interpr1.cxx | 6 -
sc/source/core/tool/interpr2.cxx | 14 ++--
sc/source/core/tool/interpr4.cxx | 12 +--
sc/source/core/tool/navicfg.cxx | 10 +-
sc/source/core/tool/optutil.cxx | 4 -
sc/source/core/tool/progress.cxx | 2
sc/source/core/tool/queryentry.cxx | 2
sc/source/core/tool/rangenam.cxx | 4 -
sc/source/core/tool/rangeseq.cxx | 2
sc/source/core/tool/refupdat.cxx | 12 +--
sc/source/core/tool/stringutil.cxx | 4 -
sc/source/core/tool/token.cxx | 6 -
sc/source/core/tool/unitconv.cxx | 4 -
sc/source/core/tool/viewopti.cxx | 2
sc/source/filter/dif/difimp.cxx | 4 -
sc/source/filter/excel/excdoc.cxx | 2
sc/source/filter/excel/excimp8.cxx | 2
sc/source/filter/excel/impop.cxx | 2
sc/source/filter/excel/xeescher.cxx | 2
sc/source/filter/excel/xichart.cxx | 4 -
sc/source/filter/excel/xiformula.cxx | 2
sc/source/filter/excel/xipivot.cxx | 4 -
sc/source/filter/excel/xlpivot.cxx | 8 +-
sc/source/filter/excel/xlroot.cxx | 2
74 files changed, 410 insertions(+), 407 deletions(-)
New commits:
commit f276ef3f7f6ecc584b77a196236852bc6ff415cc
Author: Christian M. Heller <christian.heller63 at gmail.com>
Date: Tue Nov 11 04:51:00 2014 -0500
fdo#39468 Translate German Comments - replace '//!' with '//TODO:'
It seems that most comments starting with '//!' were intended as FIXMEs.
This replaces gerrit 12241.
Conflicts:
sc/source/core/tool/token.cxx
sc/source/filter/excel/xlpivot.cxx
Change-Id: I6ed06b32c70cc854a896dbbc386565e6fbfa9b28
Reviewed-on: https://gerrit.libreoffice.org/12361
Reviewed-by: Caolán McNamara <caolanm at redhat.com>
Tested-by: Caolán McNamara <caolanm at redhat.com>
diff --git a/sc/source/core/data/column3.cxx b/sc/source/core/data/column3.cxx
index 8173e67..5170d14 100644
--- a/sc/source/core/data/column3.cxx
+++ b/sc/source/core/data/column3.cxx
@@ -1808,7 +1808,7 @@ void ScColumn::SetEditText( sc::ColumnBlockPosition& rBlockPos, SCROW nRow, cons
return;
}
- //! another "spool"
+ // rats, yet another "spool"
// Sadly there is no other way to change the Pool than to
// "spool" the Object through a corresponding Engine
EditEngine& rEngine = pDocument->GetEditEngine();
@@ -1825,7 +1825,7 @@ void ScColumn::SetEditText( SCROW nRow, const EditTextObject& rEditText, const S
return;
}
- //! another "spool"
+ // rats, yet another "spool"
// Sadly there is no other way to change the Pool than to
// "spool" the Object through a corresponding Engine
EditEngine& rEngine = pDocument->GetEditEngine();
diff --git a/sc/source/core/data/dbdocutl.cxx b/sc/source/core/data/dbdocutl.cxx
index f99aaf0..5d51fe8 100644
--- a/sc/source/core/data/dbdocutl.cxx
+++ b/sc/source/core/data/dbdocutl.cxx
@@ -46,7 +46,7 @@ void ScDatabaseDocUtil::PutData( ScDocument* pDoc, SCCOL nCol, SCROW nRow, SCTAB
bool bError = false;
sal_uLong nFormatIndex = 0;
- //! wasNull calls only if null value was found?
+ // wasNull calls only if null value was found?
try
{
@@ -54,7 +54,7 @@ void ScDatabaseDocUtil::PutData( ScDocument* pDoc, SCCOL nCol, SCROW nRow, SCTAB
{
case sdbc::DataType::BIT:
case sdbc::DataType::BOOLEAN:
- //! use language from doc (here, date/time and currency)?
+ //TODO: use language from doc (here, date/time and currency)?
nFormatIndex = pDoc->GetFormatTable()->GetStandardFormat(
NUMBERFORMAT_LOGICAL, ScGlobal::eLnge );
nVal = (xRow->getBoolean(nRowPos) ? 1 : 0);
@@ -71,7 +71,7 @@ void ScDatabaseDocUtil::PutData( ScDocument* pDoc, SCCOL nCol, SCROW nRow, SCTAB
case sdbc::DataType::DOUBLE:
case sdbc::DataType::NUMERIC:
case sdbc::DataType::DECIMAL:
- //! do the conversion here?
+ //TODO: do the conversion here?
nVal = xRow->getDouble(nRowPos);
bEmptyFlag = ( nVal == 0.0 ) && xRow->wasNull();
bValue = true;
diff --git a/sc/source/core/data/documen3.cxx b/sc/source/core/data/documen3.cxx
index f35d941..b98e43d 100644
--- a/sc/source/core/data/documen3.cxx
+++ b/sc/source/core/data/documen3.cxx
@@ -1091,9 +1091,9 @@ void ScDocument::UpdateTranspose( const ScAddress& rDestPos, ScDocument* pClipDo
void ScDocument::UpdateGrow( const ScRange& rArea, SCCOL nGrowX, SCROW nGrowY )
{
- //! pDBCollection
- //! pPivotCollection
- //! UpdateChartRef
+ //TODO: pDBCollection
+ //TODO: pPivotCollection
+ //TODO: UpdateChartRef
if (pRangeName)
pRangeName->UpdateGrow( rArea, nGrowX, nGrowY );
diff --git a/sc/source/core/data/documen4.cxx b/sc/source/core/data/documen4.cxx
index 2ab0088..e593351 100644
--- a/sc/source/core/data/documen4.cxx
+++ b/sc/source/core/data/documen4.cxx
@@ -608,7 +608,7 @@ bool ScDocument::GetSelectionFunction( ScSubTotalFunc eFunc,
if (maTabs[*itr])
maTabs[*itr]->UpdateSelectionFunction(aData, aMark);
- //TODO: pass rMark to UpdateSelectionFunction !!!!!
+ //TODO: pass rMark to UpdateSelection Function !!!!!
if (!aData.bError)
switch (eFunc)
@@ -943,7 +943,8 @@ sal_uInt16 ScDocument::ColDifferences( SCCOL nThisCol, SCTAB nThisTab,
ScDocument& rOtherDoc, SCCOL nOtherCol, SCTAB nOtherTab,
SCROW nMaxRow, SCCOLROW* pOtherRows )
{
- //TODO: Optimize e.g. with Iterator
+
+ //TODO: optimize e.g. with iterator?
sal_uLong nDif = 0;
sal_uLong nUsed = 0;
@@ -992,7 +993,9 @@ void ScDocument::FindOrder( SCCOLROW* pOtherRows, SCCOLROW nThisEndRow, SCCOLROW
{
nMaxCont = SC_DOCCOMP_COLUMNS; // 10 columns
nMinGood = SC_DOCCOMP_MINGOOD;
+
//TODO: additional pass with nMinGood = 0 ????
+
}
else
{
@@ -1155,6 +1158,7 @@ void ScDocument::CompareDocument( ScDocument& rOtherDoc )
sal_uLong n1,n2; // for AppendDeleteRange
//TODO: one Progress over all tables ???
+
OUString aTabName;
GetName( nThisTab, aTabName );
OUString aTemplate = ScGlobal::GetRscString(STR_PROGRESS_COMPARING);
diff --git a/sc/source/core/data/documen5.cxx b/sc/source/core/data/documen5.cxx
index b01d955..d499ec9 100644
--- a/sc/source/core/data/documen5.cxx
+++ b/sc/source/core/data/documen5.cxx
@@ -725,7 +725,7 @@ void ScDocument::UpdateChartListenerCollection()
// put into list of other ole objects, so the object doesn't have to
// be swapped in the next time UpdateChartListenerCollection is called
- //! remove names when objects are no longer there?
+ //TODO: remove names when objects are no longer there?
// (object names aren't used again before reloading the document)
rNonOleObjects.insert(aObjName);
diff --git a/sc/source/core/data/documen7.cxx b/sc/source/core/data/documen7.cxx
index a627f43..babd82e 100644
--- a/sc/source/core/data/documen7.cxx
+++ b/sc/source/core/data/documen7.cxx
@@ -412,8 +412,8 @@ void ScDocument::CalcFormulaTree( bool bOnlyForced, bool bProgressBar, bool bSet
bool bOldIdleEnabled = IsIdleEnabled();
EnableIdle(false);
bool bOldAutoCalc = GetAutoCalc();
- //! _nicht_ SetAutoCalc( true ) weil das evtl. CalcFormulaTree( true )
- //! aufruft, wenn vorher disabled war und bHasForcedFormulas gesetzt ist
+ //ATTENTION: _not_ SetAutoCalc( true ) because this might call CalcFormulaTree( true )
+ //ATTENTION: if it was disabled before and bHasForcedFormulas is set
bAutoCalc = true;
if ( bHardRecalcState )
CalcAll();
diff --git a/sc/source/core/data/documen9.cxx b/sc/source/core/data/documen9.cxx
index 4fe1a11..f261516 100644
--- a/sc/source/core/data/documen9.cxx
+++ b/sc/source/core/data/documen9.cxx
@@ -504,8 +504,8 @@ bool ScDocument::IsPrintEmpty( SCTAB nTab, SCCOL nStartCol, SCROW nStartRow,
if ( nStartCol > 0 && !bLeftIsEmpty )
{
- // aehnlich wie in ScPrintFunc::AdjustPrintArea
- //! ExtendPrintArea erst ab Start-Spalte des Druckbereichs
+ // similar to in ScPrintFunc::AdjustPrintArea
+ // ExtendPrintArea starting only from the start column of the print area
SCCOL nExtendCol = nStartCol - 1;
SCROW nTmpRow = nEndRow;
diff --git a/sc/source/core/data/document.cxx b/sc/source/core/data/document.cxx
index 1a377bb..64a4284 100644
--- a/sc/source/core/data/document.cxx
+++ b/sc/source/core/data/document.cxx
@@ -2283,7 +2283,7 @@ void copyUsedNamesToClip(ScRangeName* pClipRangeName, ScRangeName* pRangeName, c
{
pClipRangeName->clear();
ScRangeName::const_iterator itr = pRangeName->begin(), itrEnd = pRangeName->end();
- for (; itr != itrEnd; ++itr) //! DB-Bereiche Pivot-Bereiche auch !!!
+ for (; itr != itrEnd; ++itr) //TODO: also DB and Pivot regions!!!
{
sal_uInt16 nIndex = itr->second->GetIndex();
bool bInUse = (rUsedNames.count(nIndex) > 0);
@@ -4981,7 +4981,7 @@ void ScDocument::GetBorderLines( SCCOL nCol, SCROW nRow, SCTAB nTab,
const SvxBorderLine** ppLeft, const SvxBorderLine** ppTop,
const SvxBorderLine** ppRight, const SvxBorderLine** ppBottom ) const
{
- //! Seitengrenzen fuer Druck beruecksichtigen !!!!!
+ //TODO: consider page limits for printing !!!!!
const SvxBoxItem* pThisAttr = static_cast<const SvxBoxItem*>( GetEffItem( nCol, nRow, nTab, ATTR_BORDER ) );
OSL_ENSURE(pThisAttr,"where is the attribute?");
@@ -5216,7 +5216,7 @@ bool ScDocument::ExtendOverlapped( SCCOL& rStartCol, SCROW& rStartRow,
IsVerOverlapped())
--rStartRow;
- //! weiterreichen ?
+ //TODO: pass on ?
ScAttrArray* pAttrArray = maTabs[nTab]->aCol[nOldCol].pAttrArray;
SCSIZE nIndex;
diff --git a/sc/source/core/data/dpgroup.cxx b/sc/source/core/data/dpgroup.cxx
index dcfa706..49edcfb 100644
--- a/sc/source/core/data/dpgroup.cxx
+++ b/sc/source/core/data/dpgroup.cxx
@@ -462,7 +462,7 @@ ScDPNumGroupDimension::~ScDPNumGroupDimension()
void ScDPNumGroupDimension::SetDateDimension()
{
- aGroupInfo.mbEnable = true; //! or query both?
+ aGroupInfo.mbEnable = true; //TODO: or query both?
mbDateDimension = true;
}
@@ -514,7 +514,7 @@ void ScDPGroupTableData::SetNumGroupDimension( long nIndex, const ScDPNumGroupDi
long ScDPGroupTableData::GetDimensionIndex( const OUString& rName )
{
for (long i = 0; i < nSourceCount; ++i) // nSourceCount excludes data layout
- if (pSourceData->getDimensionName(i).equals(rName)) //! ignore case?
+ if (pSourceData->getDimensionName(i).equals(rName)) //TODO: ignore case?
return i;
return -1; // none
}
diff --git a/sc/source/core/data/dpsave.cxx b/sc/source/core/data/dpsave.cxx
index 949a997..0fb2b3d 100644
--- a/sc/source/core/data/dpsave.cxx
+++ b/sc/source/core/data/dpsave.cxx
@@ -61,7 +61,7 @@ using ::std::unique_ptr;
static void lcl_SetBoolProperty( const uno::Reference<beans::XPropertySet>& xProp,
const OUString& rName, bool bValue )
{
- //! move to ScUnoHelpFunctions?
+ //TODO: move to ScUnoHelpFunctions?
xProp->setPropertyValue( rName, uno::Any( &bValue, getBooleanCppuType() ) );
}
@@ -1151,7 +1151,7 @@ void ScDPSaveData::WriteToSource( const uno::Reference<sheet::XDimensionsSupplie
if ( xSourceProp.is() )
{
// source options are not available for external sources
- //! use XPropertySetInfo to test for availability?
+ //TODO: use XPropertySetInfo to test for availability?
try
{
@@ -1176,8 +1176,8 @@ void ScDPSaveData::WriteToSource( const uno::Reference<sheet::XDimensionsSupplie
try
{
// reset all orientations
- //! "forgetSettings" or similar at source ?????
- //! reset all duplicated dimensions, or reuse them below !!!
+ //TODO: "forgetSettings" or similar at source ?????
+ //TODO: reset all duplicated dimensions, or reuse them below !!!
OSL_FAIL( "ScDPSaveData::WriteToSource" );
lcl_ResetOrient( xSource );
@@ -1196,7 +1196,7 @@ void ScDPSaveData::WriteToSource( const uno::Reference<sheet::XDimensionsSupplie
bool bData = iter->IsDataLayout();
- //! getByName for ScDPSource, including DataLayoutDimension !!!!!!!!
+ //TODO: getByName for ScDPSource, including DataLayoutDimension !!!!!!!!
bool bFound = false;
for (long nIntDim=0; nIntDim<nIntCount && !bFound; nIntDim++)
@@ -1209,7 +1209,7 @@ void ScDPSaveData::WriteToSource( const uno::Reference<sheet::XDimensionsSupplie
{
bFound = ScUnoHelpFunctions::GetBoolProperty( xDimProp,
OUString(SC_UNO_DP_ISDATALAYOUT) );
- //! error checking -- is "IsDataLayoutDimension" property required??
+ //TODO: error checking -- is "IsDataLayoutDimension" property required??
}
}
else
diff --git a/sc/source/core/data/dpsdbtab.cxx b/sc/source/core/data/dpsdbtab.cxx
index 706357c..460fdab 100644
--- a/sc/source/core/data/dpsdbtab.cxx
+++ b/sc/source/core/data/dpsdbtab.cxx
@@ -75,7 +75,7 @@ ScDatabaseDPData::~ScDatabaseDPData()
void ScDatabaseDPData::DisposeData()
{
- //! use OpenDatabase here?
+ //TODO: use OpenDatabase here?
aCacheTable.clear();
}
@@ -89,7 +89,7 @@ OUString ScDatabaseDPData::getDimensionName(long nColumn)
{
if (getIsDataLayoutDimension(nColumn))
{
- //! different internal and display names?
+ //TODO: different internal and display names?
//return "Data";
return ScGlobal::GetRscString(STR_PIVOT_DATA);
}
@@ -105,14 +105,14 @@ bool ScDatabaseDPData::getIsDataLayoutDimension(long nColumn)
bool ScDatabaseDPData::IsDateDimension(long /* nDim */)
{
- //! later...
+ //TODO: later...
return false;
}
void ScDatabaseDPData::SetEmptyFlags( bool /* bIgnoreEmptyRows */, bool /* bRepeatIfEmpty */ )
{
// not used for database data
- //! disable flags
+ //TODO: disable flags
}
void ScDatabaseDPData::CreateCacheTable()
diff --git a/sc/source/core/data/dpshttab.cxx b/sc/source/core/data/dpshttab.cxx
index 64e0fca..08a2421 100644
--- a/sc/source/core/data/dpshttab.cxx
+++ b/sc/source/core/data/dpshttab.cxx
@@ -85,7 +85,7 @@ OUString ScSheetDPData::getDimensionName(long nColumn)
CreateCacheTable();
if (getIsDataLayoutDimension(nColumn))
{
- //! different internal and display names?
+ //TODO: different internal and display names?
//return "Data";
return ScGlobal::GetRscString(STR_PIVOT_DATA);
}
diff --git a/sc/source/core/data/dputil.cxx b/sc/source/core/data/dputil.cxx
index 362437f..c8a18e9 100644
--- a/sc/source/core/data/dputil.cxx
+++ b/sc/source/core/data/dputil.cxx
@@ -131,7 +131,7 @@ OUString ScDPUtil::getDateGroupName(
}
case sheet::DataPilotFieldGroupBy::HOURS:
{
- //! allow am/pm format?
+ //TODO: allow am/pm format?
return getTwoDigitString(nValue);
}
break;
diff --git a/sc/source/core/data/drwlayer.cxx b/sc/source/core/data/drwlayer.cxx
index 23e0de3..9d68ca3 100644
--- a/sc/source/core/data/drwlayer.cxx
+++ b/sc/source/core/data/drwlayer.cxx
@@ -91,7 +91,7 @@ static sal_uInt16 nInst = 0;
SfxObjectShell* ScDrawLayer::pGlobalDrawPersist = NULL;
-bool bDrawIsInUndo = false; //! Member
+bool bDrawIsInUndo = false; //TODO: Member
ScUndoObjData::ScUndoObjData( SdrObject* pObjP, const ScAddress& rOS, const ScAddress& rOE,
const ScAddress& rNS, const ScAddress& rNE ) :
@@ -668,7 +668,7 @@ void ScDrawLayer::RecalcPos( SdrObject* pObj, ScDrawObjData& rData, bool bNegati
Point aOrigEndPos(pObj->GetPoint(1));
aCalcPoly.append(basegfx::B2DPoint(aOrigStartPos.X(), aOrigStartPos.Y()));
aCalcPoly.append(basegfx::B2DPoint(aOrigEndPos.X(), aOrigEndPos.Y()));
- //! nicht mehrere Undos fuer ein Objekt erzeugen (hinteres kann dann weggelassen werden)
+ //TODO: do not create multiple Undos for one object (last one can be omitted then)
SCCOL nLastCol;
SCROW nLastRow;
@@ -920,7 +920,7 @@ bool ScDrawLayer::GetPrintArea( ScRange& rRange, bool bSetHor, bool bSetVer ) co
SdrObject* pObject = aIter.Next();
while (pObject)
{
- //! Flags (ausgeblendet?) testen
+ //TODO: test Flags (hidden?)
Rectangle aObjRect = pObject->GetCurrentBoundRect();
bool bFit = true;
@@ -972,7 +972,7 @@ bool ScDrawLayer::GetPrintArea( ScRange& rRange, bool bSetHor, bool bSetVer ) co
rRange.aStart.SetCol( i>0 ? (i-1) : 0 );
nWidth = 0;
- for (i=0; i<=MAXCOL && nWidth<=nEndX; i++) //! bei Start anfangen
+ for (i=0; i<=MAXCOL && nWidth<=nEndX; i++) //TODO: start at Start
nWidth += pDoc->GetColWidth(i,nTab);
rRange.aEnd.SetCol( i>0 ? (i-1) : 0 );
}
@@ -1047,7 +1047,7 @@ void ScDrawLayer::MoveArea( SCTAB nTab, SCCOL nCol1,SCROW nRow1, SCCOL nCol2,SCR
Rectangle aRect = pDoc->GetMMRect( nCol1, nRow1, nCol2, nRow2, nTab );
lcl_ReverseTwipsToMM( aRect );
- //! use twips directly?
+ //TODO: use twips directly?
Point aMove;
@@ -1123,7 +1123,7 @@ bool ScDrawLayer::HasObjectsInRows( SCTAB nTab, SCROW nStartRow, SCROW nEndRow )
SdrObject* pObject = aIter.Next();
while ( pObject && !bFound )
{
- aObjRect = pObject->GetSnapRect(); //! GetLogicRect ?
+ aObjRect = pObject->GetSnapRect(); //TODO: GetLogicRect ?
if (aTestRect.IsInside(aObjRect.TopLeft()) || aTestRect.IsInside(aObjRect.BottomLeft()))
bFound = true;
@@ -1274,7 +1274,7 @@ void ScDrawLayer::CopyToClip( ScDocument* pClipDoc, SCTAB nTab, const Rectangle&
{
// allocate drawing layer in clipboard document only if there are objects to copy
- pClipDoc->InitDrawLayer(); //! create contiguous pages
+ pClipDoc->InitDrawLayer(); //TODO: create contiguous pages
pDestModel = pClipDoc->GetDrawLayer();
}
if (pDestModel)
@@ -1359,7 +1359,7 @@ void ScDrawLayer::CopyFromClip( ScDrawLayer* pClipModel, SCTAB nSourceTab, const
if (!pClipModel)
return;
- if (bDrawIsInUndo) //! can this happen?
+ if (bDrawIsInUndo) //TODO: can this happen?
{
OSL_FAIL("CopyFromClip, bDrawIsInUndo");
return;
diff --git a/sc/source/core/data/formulacell.cxx b/sc/source/core/data/formulacell.cxx
index a7f4813..579b1e7 100644
--- a/sc/source/core/data/formulacell.cxx
+++ b/sc/source/core/data/formulacell.cxx
@@ -803,7 +803,7 @@ ScFormulaCell::ScFormulaCell( const ScFormulaCell& rCell, ScDocument& rDoc, cons
pCode->SetCodeError( 0 );
bCompile = true;
}
- //! Compile ColRowNames on URM_MOVE/URM_COPY _after_ UpdateReference
+ // Compile ColRowNames on URM_MOVE/URM_COPY _after_ UpdateReference !
bool bCompileLater = false;
bool bClipMode = rCell.pDocument->IsClipboard();
@@ -1411,7 +1411,7 @@ void ScFormulaCell::Interpret()
if (!IsDirtyOrInTableOpDirty() || pDocument->GetRecursionHelper().IsInReturn())
return; // no double/triple processing
- //! HACK:
+ //FIXME:
// If the call originates from a Reschedule in DdeLink update, leave dirty
// Better: Do a Dde Link Update without Reschedule or do it completely asynchronously!
if ( pDocument->IsInDdeLinkUpdate() )
diff --git a/sc/source/core/data/global.cxx b/sc/source/core/data/global.cxx
index 9189ba8..a9a2ae8 100644
--- a/sc/source/core/data/global.cxx
+++ b/sc/source/core/data/global.cxx
@@ -632,9 +632,9 @@ void ScGlobal::Clear()
DELETEZ(pCaseCollator);
DELETEZ(pCollator);
DELETEZ(pCalendar);
- //! do NOT delete pCharClass since it is a pointer to the single SvtSysLocale instance
+ // Do NOT delete pCharClass since it is a pointer to the single SvtSysLocale instance !
pCharClass = NULL;
- //! do NOT delete pLocaleData since it is a pointer to the single SvtSysLocale instance
+ // Do NOT delete pLocaleData since it is a pointer to the single SvtSysLocale instance !
pLocaleData = NULL;
DELETEZ(pSysLocale);
DELETEZ(pLocale);
diff --git a/sc/source/core/data/global2.cxx b/sc/source/core/data/global2.cxx
index 93da6d3..afafff4 100644
--- a/sc/source/core/data/global2.cxx
+++ b/sc/source/core/data/global2.cxx
@@ -99,7 +99,7 @@ bool ScImportParam::operator==( const ScImportParam& rOther ) const
bSql == rOther.bSql &&
nType == rOther.nType );
- //! nQuerySh und pConnection sind gleich ?
+ //TODO: are nQuerySh and pConnection equal ?
}
// struct ScConsolidateParam:
diff --git a/sc/source/core/data/markdata.cxx b/sc/source/core/data/markdata.cxx
index 08b8349..687f1ab 100644
--- a/sc/source/core/data/markdata.cxx
+++ b/sc/source/core/data/markdata.cxx
@@ -113,7 +113,7 @@ void ScMarkData::SetMarkArea( const ScRange& rRange )
void ScMarkData::GetMarkArea( ScRange& rRange ) const
{
- rRange = aMarkRange; //! inline ?
+ rRange = aMarkRange; //TODO: inline ?
}
void ScMarkData::GetMultiMarkArea( ScRange& rRange ) const
@@ -296,7 +296,7 @@ bool ScMarkData::IsCellMarked( SCCOL nCol, SCROW nRow, bool bNoSimple ) const
if (bMultiMarked)
{
- //! hier auf negative Markierung testen ?
+ //TODO: test here for negative Marking ?
OSL_ENSURE(pMultiSel, "bMultiMarked, but pMultiSel == 0");
return pMultiSel[nCol].GetMark( nRow );
@@ -307,8 +307,8 @@ bool ScMarkData::IsCellMarked( SCCOL nCol, SCROW nRow, bool bNoSimple ) const
bool ScMarkData::IsColumnMarked( SCCOL nCol ) const
{
- // bMarkIsNeg inzwischen auch fuer Spaltenkoepfe
- //! GetMarkColumnRanges fuer komplett markierte Spalten
+ // bMarkIsNeg meanwhile also for columns heads
+ //TODO: GetMarkColumnRanges for completely marked column
if ( bMarked && !bMarkIsNeg &&
aMarkRange.aStart.Col() <= nCol && aMarkRange.aEnd.Col() >= nCol &&
@@ -323,8 +323,8 @@ bool ScMarkData::IsColumnMarked( SCCOL nCol ) const
bool ScMarkData::IsRowMarked( SCROW nRow ) const
{
- // bMarkIsNeg inzwischen auch fuer Zeilenkoepfe
- //! GetMarkRowRanges fuer komplett markierte Zeilen
+ // bMarkIsNeg meanwhile also for row heads
+ //TODO: GetMarkRowRanges for completely marked rows
if ( bMarked && !bMarkIsNeg &&
aMarkRange.aStart.Col() == 0 && aMarkRange.aEnd.Col() == MAXCOL &&
@@ -377,7 +377,7 @@ void ScMarkData::FillRangeListWithMarks( ScRangeList* pList, bool bClear ) const
if (bClear)
pList->RemoveAll();
- //! bei mehreren selektierten Tabellen mehrere Ranges eintragen !!!
+ //TODO: for muliple selected tables enter multiple ranges !!!
if ( bMultiMarked )
{
@@ -427,7 +427,7 @@ void ScMarkData::ExtendRangeListTables( ScRangeList* pList ) const
return;
ScRangeList aOldList(*pList);
- pList->RemoveAll(); //! oder die vorhandenen unten weglassen
+ pList->RemoveAll(); //TODO: or skip the existing below
std::set<SCTAB>::const_iterator it = maTabMarked.begin();
for (; it != maTabMarked.end(); ++it)
diff --git a/sc/source/core/data/patattr.cxx b/sc/source/core/data/patattr.cxx
index 0e9f930..99a398f 100644
--- a/sc/source/core/data/patattr.cxx
+++ b/sc/source/core/data/patattr.cxx
@@ -513,7 +513,7 @@ void ScPatternAttr::FillToEditItemSet( SfxItemSet& rEditSet, const SfxItemSet& r
bool bHyphenate;
SvxFrameDirection eDirection;
- //! additional parameter to control if language is needed?
+ //TODO: additional parameter to control if language is needed?
if ( pCondSet )
{
@@ -1104,7 +1104,7 @@ bool ScPatternAttr::IsVisibleEqual( const ScPatternAttr& rOther ) const
OneEqual( rThisSet, rOtherSet, ATTR_BORDER_BLTR ) &&
OneEqual( rThisSet, rOtherSet, ATTR_SHADOW );
- //! auch hier nur wirklich sichtbare Werte testen !!!
+ //TODO: also here only check really visible values !!!
}
const OUString* ScPatternAttr::GetStyleName() const
@@ -1145,9 +1145,9 @@ void ScPatternAttr::UpdateStyleSheet(ScDocument* pDoc)
{
pStyle = static_cast<ScStyleSheet*>(pDoc->GetStyleSheetPool()->Find(*pName, SFX_STYLE_FAMILY_PARA));
- // wenn Style nicht gefunden, Standard nehmen,
- // damit keine leere Anzeige im Toolbox-Controller
- //! es wird vorausgesetzt, dass "Standard" immer der erste Eintrag ist!
+ // use Standard if Style is not found,
+ // to avoid empty display in Toolbox-Controller
+ // Assumes that "Standard" is always the 1st entry!
if (!pStyle)
{
SfxStyleSheetIteratorPtr pIter = pDoc->GetStyleSheetPool()->CreateIterator( SFX_STYLE_FAMILY_PARA, SFXSTYLEBIT_ALL );
diff --git a/sc/source/core/data/sortparam.cxx b/sc/source/core/data/sortparam.cxx
index e4e4dcc..235201d 100644
--- a/sc/source/core/data/sortparam.cxx
+++ b/sc/source/core/data/sortparam.cxx
@@ -192,7 +192,7 @@ ScSortParam::ScSortParam( const ScQueryParam& rParam, SCCOL nCol ) :
nCol1(nCol),nRow1(rParam.nRow1),nCol2(nCol),nRow2(rParam.nRow2),nUserIndex(0),
bHasHeader(rParam.bHasHeader),bByRow(true),bCaseSens(rParam.bCaseSens),
bNaturalSort(false),
-//! TODO: what about Locale and Algorithm?
+//TODO: what about Locale and Algorithm?
bUserDef(false),bIncludePattern(false),
bInplace(true),
nDestTab(0),nDestCol(0),nDestRow(0), nCompatHeader(2)
diff --git a/sc/source/core/data/stlpool.cxx b/sc/source/core/data/stlpool.cxx
index 71ac759..a7dfe9c 100644
--- a/sc/source/core/data/stlpool.cxx
+++ b/sc/source/core/data/stlpool.cxx
@@ -80,7 +80,7 @@ SfxStyleSheetBase& ScStyleSheetPool::Make( const OUString& rName,
// files with multiple default styles.
// Create new styles in that case:
- //! only when loading?
+ //TODO: only when loading?
if ( rName == STRING_STANDARD && Find( rName, eFam ) != NULL )
{
diff --git a/sc/source/core/data/stlsheet.cxx b/sc/source/core/data/stlsheet.cxx
index 0d264b0..552e5d6 100644
--- a/sc/source/core/data/stlsheet.cxx
+++ b/sc/source/core/data/stlsheet.cxx
@@ -293,13 +293,12 @@ const OUString& ScStyleSheet::GetFollow() const
return rBase;
}
-// Verhindern, dass ein Style "Standard" angelegt wird, wenn das nicht der
-// Standard-Name ist, weil sonst beim Speichern zwei Styles denselben Namen haetten
-// (Beim Laden wird der Style direkt per Make mit dem Namen erzeugt, so dass diese
-// Abfrage dann nicht gilt)
-//! Wenn irgendwann aus dem Laden SetName aufgerufen wird, muss fuer das Laden ein
-//! Flag gesetzt und abgefragt werden.
-//! Die ganze Abfrage muss raus, wenn fuer eine neue Datei-Version die Namens-Umsetzung wegfaellt.
+// Avoid creating a Style "Standard" if this is not the Standard-Name;
+// otherwise two styles would have the same name when storing.
+// (on loading the style is created directly per Make with the name; making this query
+// not applicable)
+//TODO: If at any time during loading SetName is called, a flag has to be set/checked for loading
+//TODO: The whole check has to be removed if for a new file version the name transformation is dropped.
bool ScStyleSheet::SetName(const OUString& rNew, bool bReindexNow)
{
diff --git a/sc/source/core/data/table1.cxx b/sc/source/core/data/table1.cxx
index 654bf4a..1aa5430 100644
--- a/sc/source/core/data/table1.cxx
+++ b/sc/source/core/data/table1.cxx
@@ -548,7 +548,7 @@ bool ScTable::GetCellArea( SCCOL& rEndCol, SCROW& rEndRow ) const
bool ScTable::GetTableArea( SCCOL& rEndCol, SCROW& rEndRow ) const
{
- bool bRet = true; //! merken?
+ bool bRet = true; //TODO: remember?
if (!bTableAreaValid)
{
bRet = GetPrintArea(nTableAreaX, nTableAreaY, true);
@@ -676,7 +676,7 @@ bool ScTable::GetPrintAreaHor( SCROW nStartRow, SCROW nEndRow,
for (i=0; i<=MAXCOL; i++) // Daten testen
{
- if (!aCol[i].IsEmptyBlock( nStartRow, nEndRow )) //! bNotes ??????
+ if (!aCol[i].IsEmptyBlock( nStartRow, nEndRow )) //TODO: bNotes ??????
{
bFound = true;
if (i>nMaxX)
@@ -1203,11 +1203,11 @@ bool ScTable::ValidNextPos( SCCOL nCol, SCROW nRow, const ScMarkData& rMark,
GetAttr(nCol,nRow,ATTR_PROTECTION))->GetProtection())
return false;
- if (bMarked || bUnprotected) //! auch sonst ???
+ if (bMarked || bUnprotected) //TODO: also in other case ???
{
- // ausgeblendete muessen uebersprungen werden, weil der Cursor sonst
- // auf der naechsten Zelle landet, auch wenn die geschuetzt/nicht markiert ist.
- //! per Extra-Parameter steuern, nur fuer Cursor-Bewegung ???
+ // Hidden cells must be skipped, as the cursor would end up on the next cell
+ // even if it is protected or not marked.
+ //TODO: control per Extra-Parameter, only for Cursor movement ???
if (RowHidden(nRow))
return false;
@@ -1794,10 +1794,10 @@ void ScTable::MaybeAddExtraColumn(SCCOL& rCol, SCROW nRow, OutputDevice* pDev, d
if (!aCell.hasString())
return;
- bool bFormula = false; //! ueberge
+ bool bFormula = false; //TODO: pass as parameter
long nPixel = aCol[rCol].GetTextWidth(nRow);
- // Breite bereits im Idle-Handler berechnet?
+ // Width already calculated in Idle-Handler ?
if ( TEXTWIDTH_DIRTY == nPixel )
{
ScNeededSizeOptions aOptions;
diff --git a/sc/source/core/data/table2.cxx b/sc/source/core/data/table2.cxx
index 938639b..adc1626 100644
--- a/sc/source/core/data/table2.cxx
+++ b/sc/source/core/data/table2.cxx
@@ -1129,7 +1129,7 @@ void ScTable::CopyToTable(
pDestTab->pColWidth[i] = pColWidth[i];
pDestTab->pColFlags[i] = pColFlags[i];
pDestTab->SetColHidden(i, i, bThisHidden);
- //! Aenderungen zusammenfassen?
+ //TODO: collect changes?
if (bHiddenChange && pCharts)
pCharts->SetRangeDirty(ScRange( i, 0, nTab, i, MAXROW, nTab ));
@@ -1957,11 +1957,11 @@ SCSIZE ScTable::FillMaxRot( RowInfo* pRowInfo, SCSIZE nArrCount, SCCOL nX1, SCCO
double nRealOrient = nRotVal * F_PI18000; // 1/100 Grad
double nCos = cos( nRealOrient );
double nSin = sin( nRealOrient );
- //! begrenzen !!!
- //! zusaetzlich Faktor fuer unterschiedliche PPT X/Y !!!
+ //TODO: limit !!!
+ //TODO: additional factor for varying PPT X/Y !!!
- // bei SC_ROTDIR_LEFT kommt immer ein negativer Wert heraus,
- // wenn der Modus beruecksichtigt wird
+ // for SC_ROTDIR_LEFT this gives a negative value,
+ // if the Modus is considered
nFactor = -fabs( nCos / nSin );
}
@@ -3024,7 +3024,7 @@ SCROW ScTable::GetHiddenRowCount( SCROW nRow ) const
return nLastRow - nRow + 1;
}
-//! ShowRows / DBShowRows zusammenfassen
+//TODO: combine ShowRows / DBShowRows
void ScTable::ShowCol(SCCOL nCol, bool bShow)
{
@@ -3478,7 +3478,7 @@ void ScTable::DoAutoOutline( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SC
void ScTable::CopyData( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow,
SCCOL nDestCol, SCROW nDestRow, SCTAB nDestTab )
{
- //! wenn fuer mehrere Zeilen benutzt, nach Spalten optimieren!
+ //TODO: if used for multipe rows, optimize after columns!
ScAddress aSrc( nStartCol, nStartRow, nTab );
ScAddress aDest( nDestCol, nDestRow, nDestTab );
diff --git a/sc/source/core/data/table3.cxx b/sc/source/core/data/table3.cxx
index 9aca1be..61b8059 100644
--- a/sc/source/core/data/table3.cxx
+++ b/sc/source/core/data/table3.cxx
@@ -1965,7 +1965,7 @@ bool ScTable::DoSubTotals( ScSubTotalParam& rParam )
for (i=0; i<MAXSUBTOTAL; i++)
pCompString[i] = new OUString;
- //! sortieren?
+ //TODO: sort?
ScStyleSheet* pStyle = static_cast<ScStyleSheet*>(pDocument->GetStyleSheetPool()->Find(
ScGlobal::GetRscString(STR_STYLENAME_RESULT), SFX_STYLE_FAMILY_PARA ));
@@ -2163,9 +2163,9 @@ bool ScTable::DoSubTotals( ScSubTotalParam& rParam )
}
- //! je nach Einstellung Zwischensummen-Zeilen nach oben verschieben ?
+ //TODO: according to setting, shift intermediate-sum rows up ?
- //! Outlines direkt erzeugen?
+ //TODO: create Outlines directly?
if (bSpaceLeft)
DoAutoOutline( nStartCol, nStartRow, nEndCol, nEndRow );
@@ -2173,7 +2173,7 @@ bool ScTable::DoSubTotals( ScSubTotalParam& rParam )
for (i=0; i<MAXSUBTOTAL; i++)
delete pCompString[i];
- rParam.nRow2 = nEndRow; // neues Ende
+ rParam.nRow2 = nEndRow; // new end
return bSpaceLeft;
}
diff --git a/sc/source/core/data/table4.cxx b/sc/source/core/data/table4.cxx
index 84ee54e..ee52681 100644
--- a/sc/source/core/data/table4.cxx
+++ b/sc/source/core/data/table4.cxx
@@ -634,7 +634,7 @@ void ScTable::FillAuto( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
if ( pSrcPattern != aCol[nCol].GetPattern( static_cast<SCROW>(nRow) ) )
{
// Transfer template too
- //! Merge ApplyPattern to AttrArray ??
+ //TODO: Merge ApplyPattern to AttrArray ??
if ( pStyleSheet )
aCol[nCol].ApplyStyle( static_cast<SCROW>(nRow), *pStyleSheet );
@@ -988,7 +988,7 @@ OUString ScTable::GetAutoFillPreview( const ScRange& rSource, SCCOL nEndX, SCROW
}
else
{
- //! Zahlformat je nach Index holen?
+ //TODO: get number format according to Index?
Color* pColor;
sal_uLong nNumFmt = GetNumberFormat( nCol1, nRow1 );
pDocument->GetFormatTable()->GetOutputString( nStart, nNumFmt, aValue, &pColor );
diff --git a/sc/source/core/data/table6.cxx b/sc/source/core/data/table6.cxx
index 697fa11..5272a48 100644
--- a/sc/source/core/data/table6.cxx
+++ b/sc/source/core/data/table6.cxx
@@ -601,7 +601,7 @@ bool ScTable::SearchStyle(const SvxSearchItem& rSearchItem, SCCOL& rCol, SCROW&
return bFound;
}
-//! einzelnes Pattern fuer Undo zurueckgeben
+//TODO: return single Pattern for Undo
bool ScTable::ReplaceStyle(const SvxSearchItem& rSearchItem, SCCOL& rCol, SCROW& rRow,
const ScMarkData& rMark, bool bIsUndo)
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/sc/source/core/data/column.cxx b/sc/source/core/data/column.cxx
index d7597e6..111b254 100644
--- a/sc/source/core/data/column.cxx
+++ b/sc/source/core/data/column.cxx
@@ -66,7 +66,7 @@ namespace {
inline bool IsAmbiguousScriptNonZero( sal_uInt8 nScript )
{
//! move to a header file
return ( nScript != SCRIPTTYPE_LATIN &&
nScript != SCRIPTTYPE_ASIAN &&
nScript != SCRIPTTYPE_COMPLEX &&
@@ -697,7 +697,7 @@ void ScColumn::SetPatternArea( SCROW nStartRow, SCROW nEndRow,
void ScColumn::ApplyAttr( SCROW nRow, const SfxPoolItem& rAttr )
{
// in order to only create a new SetItem, we don't need SfxItemPoolCache.
//! Warning: SfxItemPoolCache seems to create to many Refs for the new SetItem ??
ScDocumentPool* pDocPool = pDocument->GetPool();
@@ -1698,7 +1698,7 @@ void ScColumn::UndoToColumn(
if (nRow1 > 0)
CopyToColumn(rCxt, 0, nRow1-1, IDF_FORMULA, false, rColumn);
- CopyToColumn(rCxt, nRow1, nRow2, nFlags, bMarked, rColumn, pMarkData); //! bMarked ????
+ CopyToColumn(rCxt, nRow1, nRow2, nFlags, bMarked, rColumn, pMarkData); //TODO: bMarked ????
if (nRow2 < MAXROW)
CopyToColumn(rCxt, nRow2+1, MAXROW, IDF_FORMULA, false, rColumn);
@@ -1753,7 +1753,7 @@ void ScColumn::CopyScenarioFrom( const ScColumn& rSrcCol )
UpdateCompile();
}
//! make CopyToColumn "const" !!! (obsolete comment ?)
pPattern = aAttrIter.Next( nStart, nEnd );
}
@@ -1783,7 +1783,7 @@ void ScColumn::CopyScenarioTo( ScColumn& rDestCol ) const
rDestCol.UpdateCompile();
}
//! make CopyToColumn "const" !!! (obsolete comment ?)
pPattern = aAttrIter.Next( nStart, nEnd );
}
@@ -66,7 +66,7 @@ namespace {
inline bool IsAmbiguousScriptNonZero( sal_uInt8 nScript )
{
- //! move to a header file
+ //TODO: move to a header file
return ( nScript != SCRIPTTYPE_LATIN &&
nScript != SCRIPTTYPE_ASIAN &&
@@ -697,7 +697,7 @@ void ScColumn::SetPatternArea( SCROW nStartRow, SCROW nEndRow,
{
// in order to only create a new SetItem, we don't need SfxItemPoolCache.
- //! Warning: SfxItemPoolCache seems to create to many Refs for the new SetItem ??
+ //TODO: Warning: SfxItemPoolCache seems to create to many Refs for the new SetItem ??
ScDocumentPool* pDocPool = pDocument->GetPool();
@@ -1753,7 +1753,7 @@ void ScColumn::CopyScenarioFrom( const ScColumn& rSrcCol )
UpdateCompile();
}
- //! make CopyToColumn "const" !!! (obsolete comment ?)
+ //TODO: make CopyToColumn "const" !!! (obsolete comment ?)
pPattern = aAttrIter.Next( nStart, nEnd );
}
@@ -1783,7 +1783,7 @@ void ScColumn::CopyScenarioTo( ScColumn& rDestCol ) const
rDestCol.UpdateCompile();
}
- //! make CopyToColumn "const" !!! (obsolete comment ?)
+ //TODO: make CopyToColumn "const" !!! (obsolete comment ?)
pPattern = aAttrIter.Next( nStart, nEnd );
}
diff --git a/sc/source/core/data/column2.cxx b/sc/source/core/data/column2.cxx
index 9b0b5ef..779ed16 100644
--- a/sc/source/core/data/column2.cxx
+++ b/sc/source/core/data/column2.cxx
@@ -73,7 +73,7 @@
inline bool IsAmbiguousScript( sal_uInt8 nScript )
{
//! move to a header file
return ( nScript != SCRIPTTYPE_LATIN &&
nScript != SCRIPTTYPE_ASIAN &&
nScript != SCRIPTTYPE_COMPLEX );
@@ -275,7 +275,7 @@ long ScColumn::GetNeededSize(
}
else if ( nRotate )
{
//! take different X/Y scaling into consideration
double nRealOrient = nRotate * F_PI18000; // nRotate is in 1/100 Grad
double nCosAbs = fabs( cos( nRealOrient ) );
@@ -289,13 +289,13 @@ long ScColumn::GetNeededSize(
nWidth = (long) ( pDocument->GetColWidth( nCol,nTab ) * nPPT );
bAddMargin = false;
// only to the right:
//! differ on direction up/down (only Text/whole height)
if ( pPattern->GetRotateDir( pCondSet ) == SC_ROTDIR_RIGHT )
nWidth += (long)( pDocument->GetRowHeight( nRow,nTab ) *
nPPT * nCosAbs / nSinAbs );
}
else
- nWidth = (long)( aSize.Height() / nSinAbs ); //! limit?
+ nWidth = (long)( aSize.Height() / nSinAbs ); //TODO: limit?
if ( bBreak && !rOptions.bTotalSize )
{
@@ -449,7 +449,7 @@ long ScColumn::GetNeededSize(
bEdWidth = !bEdWidth;
if ( nRotate )
{
//! take different X/Y scaling into consideration
Size aSize( pEngine->CalcTextWidth(), pEngine->GetTextHeight() );
double nRealOrient = nRotate * F_PI18000; // nRotate is in 1/100 Grad
@@ -468,7 +468,7 @@ long ScColumn::GetNeededSize(
nPPT * nCosAbs / nSinAbs );
}
else
- nWidth = (long)( aSize.Height() / nSinAbs ); //! limit?
+ nWidth = (long)( aSize.Height() / nSinAbs ); //TODO: limit?
aSize = Size( nWidth, nHeight );
Size aPixSize = pDev->LogicToPixel( aSize, aHMMMode );
@@ -749,7 +749,7 @@ static sal_uInt16 lcl_GetAttribHeight( const ScPatternAttr& rPattern, sal_uInt16
GetItem(ATTR_FONT_EMPHASISMARK)).GetEmphasisMark() != EMPHASISMARK_NONE )
{
// add height for emphasis marks
//! font metrics should be used instead
nHeight += nHeight / 4;
}
@@ -73,7 +73,7 @@
inline bool IsAmbiguousScript( sal_uInt8 nScript )
{
- //! move to a header file
+ //TODO: move to a header file
return ( nScript != SCRIPTTYPE_LATIN &&
nScript != SCRIPTTYPE_ASIAN &&
@@ -275,7 +275,7 @@ long ScColumn::GetNeededSize(
else if ( nRotate )
{
- //! take different X/Y scaling into consideration
+ //TODO: take different X/Y scaling into consideration
double nRealOrient = nRotate * F_PI18000; // nRotate is in 1/100 Grad
double nCosAbs = fabs( cos( nRealOrient ) );
@@ -289,13 +289,13 @@ long ScColumn::GetNeededSize(
bAddMargin = false;
// only to the right:
- //! differ on direction up/down (only Text/whole height)
+ //TODO: differ on direction up/down (only Text/whole height)
if ( pPattern->GetRotateDir( pCondSet ) == SC_ROTDIR_RIGHT )
nWidth += (long)( pDocument->GetRowHeight( nRow,nTab ) *
@@ -449,7 +449,7 @@ long ScColumn::GetNeededSize(
if ( nRotate )
{
- //! take different X/Y scaling into consideration
+ //TODO: take different X/Y scaling into consideration
Size aSize( pEngine->CalcTextWidth(), pEngine->GetTextHeight() );
double nRealOrient = nRotate * F_PI18000; // nRotate is in 1/100 Grad
@@ -749,7 +749,7 @@ static sal_uInt16 lcl_GetAttribHeight( const ScPatternAttr& rPattern, sal_uInt16
{
// add height for emphasis marks
- //! font metrics should be used instead
+ //TODO: font metrics should be used instead
nHeight += nHeight / 4;
}
diff --git a/sc/source/core/data/conditio.cxx b/sc/source/core/data/conditio.cxx
index 4395096..d091398 100644
--- a/sc/source/core/data/conditio.cxx
+++ b/sc/source/core/data/conditio.cxx
@@ -337,7 +337,7 @@ void ScConditionEntry::Compile( const OUString& rExpr1, const OUString& rExpr2,
if ( mpDoc->IsImportingXML() && !bTextToReal )
{
// temporary formula string as string tokens
- //! merge with lcl_ScDocFunc_CreateTokenArrayXML
+ //TODO: merge with lcl_ScDocFunc_CreateTokenArrayXML
pFormula1 = new ScTokenArray;
pFormula1->AddStringXML( rExpr1 );
// bRelRef1 is set when the formula is compiled again (CompileXML)
@@ -375,7 +375,7 @@ void ScConditionEntry::Compile( const OUString& rExpr1, const OUString& rExpr2,
if ( mpDoc->IsImportingXML() && !bTextToReal )
{
// temporary formula string as string tokens
- //! merge with lcl_ScDocFunc_CreateTokenArrayXML
+ //TODO: merge with lcl_ScDocFunc_CreateTokenArrayXML
pFormula2 = new ScTokenArray;
pFormula2->AddStringXML( rExpr2 );
// bRelRef2 is set when the formula is compiled again (CompileXML)
@@ -659,7 +659,7 @@ void ScConditionEntry::Interpret( const ScAddress& rPos )
{
if (!pEff1->IsRunning()) // Don't create 522
{
//! Query Changed instead of Dirty!
if (pEff1->GetDirty() && !bRelRef1 && mpDoc->GetAutoCalc())
bDirty = true;
if (pEff1->IsValue())
@@ -1160,7 +1160,7 @@ bool ScConditionEntry::IsValidStr( const OUString& rArg, const ScAddress& rPos )
if ( !bIsStr2 )
return false;
- OUString aUpVal1( aStrVal1 ); //! As a member? (Also set in Interpret)
+ OUString aUpVal1( aStrVal1 ); //TODO: As a member? (Also set in Interpret)
OUString aUpVal2( aStrVal2 );
if ( eOp == SC_COND_BETWEEN || eOp == SC_COND_NOTBETWEEN )
@@ -659,7 +659,7 @@ void ScConditionEntry::Interpret( const ScAddress& rPos )
if (!pEff1->IsRunning()) // Don't create 522
{
- //! Query Changed instead of Dirty!
+ //TODO: Query Changed instead of Dirty!
if (pEff1->GetDirty() && !bRelRef1 && mpDoc->GetAutoCalc())
bDirty = true;
diff --git a/sc/source/core/data/documen8.cxx b/sc/source/core/data/documen8.cxx
index 42b5b95..86ce46c 100644
--- a/sc/source/core/data/documen8.cxx
+++ b/sc/source/core/data/documen8.cxx
@@ -1002,7 +1002,7 @@ bool ScDocument::CreateDdeLink( const OUString& rAppl, const OUString& rTopic, c
/* Create a DDE link without updating it (i.e. for Excel import), to prevent
unwanted connections. First try to find existing link. Set result array
on existing and new links. */
//! store DDE links additionally at document (for efficiency)?
OSL_ENSURE( nMode != SC_DDE_IGNOREMODE, "ScDocument::CreateDdeLink - SC_DDE_IGNOREMODE not allowed here" );
sfx2::LinkManager* pMgr = GetDocLinkManager().getLinkManager(bAutoCalc);
@@ -1294,7 +1294,7 @@ void ScDocument::TransliterateText( const ScMarkData& rMultiMark, sal_Int32 nTyp
if ( bConsiderLanguage )
{
- sal_uInt8 nScript = GetStringScriptType( aOldStr ); //! cell script type?
+ sal_uInt8 nScript = GetStringScriptType( aOldStr ); //TODO: cell script type?
sal_uInt16 nWhich = ( nScript == SCRIPTTYPE_ASIAN ) ? ATTR_CJK_FONT_LANGUAGE :
( ( nScript == SCRIPTTYPE_COMPLEX ) ? ATTR_CTL_FONT_LANGUAGE :
ATTR_FONT_LANGUAGE );
@@ -1002,7 +1002,7 @@ bool ScDocument::CreateDdeLink( const OUString& rAppl, const OUString& rTopic, c
unwanted connections. First try to find existing link. Set result array
on existing and new links. */
- //! store DDE links additionally at document (for efficiency)?
+ //TODO: store DDE links additionally at document (for efficiency)?
OSL_ENSURE( nMode != SC_DDE_IGNOREMODE, "ScDocument::CreateDdeLink - SC_DDE_IGNOREMODE not allowed here" );
sfx2::LinkManager* pMgr = GetDocLinkManager().getLinkManager(bAutoCalc);
diff --git a/sc/source/core/data/dpdimsave.cxx b/sc/source/core/data/dpdimsave.cxx
index 7579a16..40dcb3f 100644
--- a/sc/source/core/data/dpdimsave.cxx
+++ b/sc/source/core/data/dpdimsave.cxx
@@ -57,7 +57,7 @@ void ScDPSaveGroupItem::AddElementsFromGroup( const ScDPSaveGroupItem& rGroup )
bool ScDPSaveGroupItem::RemoveElement( const OUString& rName )
{
for (std::vector<OUString>::iterator aIter = aElements.begin(); aIter != aElements.end(); ++aIter)
- if (*aIter == rName) //! ignore case
+ if (*aIter == rName) //TODO: ignore case
{
aElements.erase(aIter); // found -> remove
return true; // don't have to look further
@@ -162,8 +162,8 @@ OUString ScDPSaveGroupDimension::CreateGroupName(const OUString& rPrefix)
{
// create a name for a new group, using "Group1", "Group2" etc. (translated prefix in rPrefix)
//! look in all dimensions, to avoid clashes with automatic groups (=name of base element)?
//! (only dimensions for the same base)
sal_Int32 nAdd = 1; // first try is "Group1"
const sal_Int32 nMaxAdd = nAdd + aGroups.size(); // limit the loop
@@ -175,7 +175,7 @@ OUString ScDPSaveGroupDimension::CreateGroupName(const OUString& rPrefix)
// look for existing groups
for ( ScDPSaveGroupItemVec::const_iterator aIter(aGroups.begin());
aIter != aGroups.end() && !bExists; ++aIter )
- if (aIter->GetGroupName().equals(aGroupName)) //! ignore case
+ if (aIter->GetGroupName().equals(aGroupName)) //TODO: ignore case
bExists = true;
if ( !bExists )
@@ -196,7 +196,7 @@ const ScDPSaveGroupItem* ScDPSaveGroupDimension::GetNamedGroup( const OUString&
ScDPSaveGroupItem* ScDPSaveGroupDimension::GetNamedGroupAcc( const OUString& rGroupName )
{
for (ScDPSaveGroupItemVec::iterator aIter = aGroups.begin(); aIter != aGroups.end(); ++aIter)
- if (aIter->GetGroupName().equals(rGroupName)) //! ignore case
+ if (aIter->GetGroupName().equals(rGroupName)) //TODO: ignore case
return &*aIter;
return NULL; // none found
@@ -235,7 +235,7 @@ void ScDPSaveGroupDimension::RemoveFromGroups( const OUString& rItemName )
void ScDPSaveGroupDimension::RemoveGroup(const OUString& rGroupName)
{
for (ScDPSaveGroupItemVec::iterator aIter = aGroups.begin(); aIter != aGroups.end(); ++aIter)
- if (aIter->GetGroupName().equals(rGroupName)) //! ignore case
+ if (aIter->GetGroupName().equals(rGroupName)) //TODO: ignore case
{
aGroups.erase( aIter );
return; // don't have to look further
@@ -324,7 +324,7 @@ void fillDateGroupDimension(
if (rDateInfo.mbAutoEnd)
rDateInfo.mfEnd = rtl::math::approxFloor(fSourceMax) + 1;
- //! if not automatic, limit fSourceMin/fSourceMax for list of year values?
+ //TODO: if not automatic, limit fSourceMin/fSourceMax for list of year values?
long nStart = 0, nEnd = 0; // end is inclusive
@@ -523,7 +523,7 @@ void ScDPSaveNumGroupDimension::AddToCache(ScDPCache& rCache) const
if (aGroupInfo.mbAutoEnd)
aGroupInfo.mfEnd = fSourceMax;
//! limit number of entries?
long nLoopCount = 0;
double fLoop = aGroupInfo.mfStart;
@@ -783,7 +783,7 @@ OUString ScDPDimensionSaveData::CreateGroupDimName(
// look for existing group dimensions
for( ScDPSaveGroupDimVec::const_iterator aIt = maGroupDims.begin(), aEnd = maGroupDims.end(); (aIt != aEnd) && !bExists; ++aIt )
- if( aIt->GetGroupDimName() == aDimName ) //! ignore case
+ if( aIt->GetGroupDimName() == aDimName ) //TODO: ignore case
bExists = true;
// look for base dimensions that happen to have that name
@@ -162,8 +162,8 @@ OUString ScDPSaveGroupDimension::CreateGroupName(const OUString& rPrefix)
{
// create a name for a new group, using "Group1", "Group2" etc. (translated prefix in rPrefix)
- //! look in all dimensions, to avoid clashes with automatic groups (=name of base element)?
- //! (only dimensions for the same base)
+ //TODO: look in all dimensions, to avoid clashes with automatic groups (=name of base element)?
+ //TODO: (only dimensions for the same base)
sal_Int32 nAdd = 1; // first try is "Group1"
const sal_Int32 nMaxAdd = nAdd + aGroups.size(); // limit the loop
@@ -523,7 +523,7 @@ void ScDPSaveNumGroupDimension::AddToCache(ScDPCache& rCache) const
if (aGroupInfo.mbAutoEnd)
aGroupInfo.mfEnd = fSourceMax;
- //! limit number of entries?
+ //TODO: limit number of entries?
long nLoopCount = 0;
double fLoop = aGroupInfo.mfStart;
diff --git a/sc/source/core/data/dpobject.cxx b/sc/source/core/data/dpobject.cxx
index fb8a3b3..ed402a2 100644
--- a/sc/source/core/data/dpobject.cxx
+++ b/sc/source/core/data/dpobject.cxx
@@ -199,7 +199,7 @@ void DBConnector::getValue(long nCol, ScDPItemData &rData, short& rNumType) cons
case sdbc::DataType::NUMERIC:
case sdbc::DataType::DECIMAL:
{
//! do the conversion here?
fValue = mxRow->getDouble(nCol+1);
rData.SetValue(fValue);
break;
@@ -275,7 +275,7 @@ sal_uInt16 lcl_GetDataGetOrientation( const uno::Reference<sheet::XDimensionsSup
{
bFound = ScUnoHelpFunctions::GetBoolProperty( xDimProp,
OUString(SC_UNO_DP_ISDATALAYOUT) );
//! error checking -- is "IsDataLayoutDimension" property required??
if (bFound)
nRet = ScUnoHelpFunctions::GetEnumProperty(
xDimProp, OUString(SC_UNO_DP_ORIENTATION),
@@ -559,7 +559,7 @@ void ScDPObject::CreateOutput()
aStart.SetRow(nNewRow);
pOutput->SetPosition( aStart );
- //! modify aOutRange?
+ //TODO: modify aOutRange?
bAllowMove = false; // use only once
}
@@ -1110,8 +1110,8 @@ void ScDPObject::UpdateReference( UpdateRefMode eUpdateRefMode,
ScQueryParam aParam = pSheetDesc->GetQueryParam();
aParam.nCol1 = sal::static_int_cast<SCCOL>( aParam.nCol1 + nDiffX );
aParam.nCol2 = sal::static_int_cast<SCCOL>( aParam.nCol2 + nDiffX );
- aParam.nRow1 += nDiffY; //! used?
- aParam.nRow2 += nDiffY; //! used?
+ aParam.nRow1 += nDiffY; //TODO: used?
+ aParam.nRow2 += nDiffY; //TODO: used?
SCSIZE nEC = aParam.GetEntryCount();
for (SCSIZE i=0; i<nEC; i++)
if (aParam.GetEntry(i).bDoQuery)
@@ -1233,7 +1233,7 @@ OUString ScDPObject::GetDimName( long nDim, bool& rIsDataLayout, sal_Int32* pFla
{
bool bData = ScUnoHelpFunctions::GetBoolProperty( xDimProp,
OUString(SC_UNO_DP_ISDATALAYOUT) );
//! error checking -- is "IsDataLayoutDimension" property required??
OUString aName;
try
@@ -1965,7 +1965,7 @@ void ScDPObject::ToggleDetails(const DataPilotTableHeaderData& rElemDesc, ScDPOb
{
bShowDetails = ScUnoHelpFunctions::GetBoolProperty( xMbrProp,
OUString(SC_UNO_DP_SHOWDETAILS) );
//! don't set bFound if property is unknown?
bFound = true;
}
}
@@ -1974,7 +1974,7 @@ void ScDPObject::ToggleDetails(const DataPilotTableHeaderData& rElemDesc, ScDPOb
OSL_ENSURE( bFound, "member not found" );
(void)bFound;
//! use Hierarchy and Level in SaveData !!!!
// modify pDestObj if set, this object otherwise
ScDPSaveData* pModifyData = pDestObj ? ( pDestObj->pSaveData ) : pSaveData;
@@ -2065,8 +2065,8 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
bool bDataFound = false;
//! merge multiple occurrences (data field with different functions)
//! force data field in one dimension
vector<long> aPos;
@@ -2100,7 +2100,7 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
sheet::GeneralFunction_NONE );
if ( eFunc == sheet::GeneralFunction_AUTO )
{
//! test for numeric data
eFunc = sheet::GeneralFunction_SUM;
}
nMask = ScDataPilotConversion::FunctionBit(eFunc);
@@ -2135,7 +2135,7 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
if ( bDataLayout )
nCompCol = PIVOT_DATA_FIELD;
else
- nCompCol = static_cast<SCsCOL>(nDupSource); //! seek source column from name
+ nCompCol = static_cast<SCsCOL>(nDupSource); //TODO: seek source column from name
ScPivotFieldVector::iterator it = std::find_if(aFields.begin(), aFields.end(), FindByColumn(nCompCol, nMask));
if (it != aFields.end())
@@ -2152,7 +2152,7 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
else
{
rField.mnOriginalDim = nDupSource;
- rField.nCol = static_cast<SCCOL>(nDim); //! seek source column from name
+ rField.nCol = static_cast<SCCOL>(nDim); //TODO: seek source column from name
}
rField.nFuncMask = nMask;
@@ -2302,7 +2302,7 @@ bool ScDPObject::FillLabelDataForDimension(
bool bData = ScUnoHelpFunctions::GetBoolProperty(
xDimProp, OUString(SC_UNO_DP_ISDATALAYOUT));
//! error checking -- is "IsDataLayoutDimension" property required??
sal_Int32 nOrigPos = -1;
OUString aFieldName;
@@ -2323,7 +2323,7 @@ bool ScDPObject::FillLabelDataForDimension(
OUString aSubtotalName = ScUnoHelpFunctions::GetStringProperty(
xDimProp, OUString(SC_UNO_DP_FIELD_SUBTOTALNAME), OUString());
- bool bIsValue = true; //! check
+ bool bIsValue = true; //TODO: check
// Name from the UNO dimension object may have trailing '*'s in which
// case it's a duplicate dimension. Convert that to a duplicate index.
@@ -3201,7 +3201,7 @@ uno::Reference<sdbc::XRowSet> ScDPCollection::DBCaches::createRowSet(
}
catch ( const sdbc::SQLException& rError )
{
//! store error message
InfoBox aInfoBox( 0, OUString(rError.Message) );
aInfoBox.Execute();
}
@@ -3520,7 +3520,7 @@ void ScDPCollection::WriteRefsTo( ScDPCollection& r ) const
{
if ( maTables.size() == r.maTables.size() )
{
- //! assert equal names?
+ //TODO: assert equal names?
TablesType::const_iterator itr = maTables.begin(), itrEnd = maTables.end();
TablesType::iterator itr2 = r.maTables.begin();
for (; itr != itrEnd; ++itr, ++itr2)
@@ -199,7 +199,7 @@ void DBConnector::getValue(long nCol, ScDPItemData &rData, short& rNumType) cons
case sdbc::DataType::DECIMAL:
{
- //! do the conversion here?
+ //TODO: do the conversion here?
fValue = mxRow->getDouble(nCol+1);
rData.SetValue(fValue);
@@ -275,7 +275,7 @@ sal_uInt16 lcl_GetDataGetOrientation( const uno::Reference<sheet::XDimensionsSup
bFound = ScUnoHelpFunctions::GetBoolProperty( xDimProp,
OUString(SC_UNO_DP_ISDATALAYOUT) );
- //! error checking -- is "IsDataLayoutDimension" property required??
+ //TODO: error checking -- is "IsDataLayoutDimension" property required??
if (bFound)
nRet = ScUnoHelpFunctions::GetEnumProperty(
@@ -1233,7 +1233,7 @@ OUString ScDPObject::GetDimName( long nDim, bool& rIsDataLayout, sal_Int32* pFla
bool bData = ScUnoHelpFunctions::GetBoolProperty( xDimProp,
OUString(SC_UNO_DP_ISDATALAYOUT) );
- //! error checking -- is "IsDataLayoutDimension" property required??
+ //TODO: error checking -- is "IsDataLayoutDimension" property required??
OUString aName;
try
@@ -1965,7 +1965,7 @@ void ScDPObject::ToggleDetails(const DataPilotTableHeaderData& rElemDesc, ScDPOb
bShowDetails = ScUnoHelpFunctions::GetBoolProperty( xMbrProp,
OUString(SC_UNO_DP_SHOWDETAILS) );
- //! don't set bFound if property is unknown?
+ //TODO: don't set bFound if property is unknown?
bFound = true;
}
@@ -1974,7 +1974,7 @@ void ScDPObject::ToggleDetails(const DataPilotTableHeaderData& rElemDesc, ScDPOb
OSL_ENSURE( bFound, "member not found" );
(void)bFound;
- //! use Hierarchy and Level in SaveData !!!!
+ //TODO: use Hierarchy and Level in SaveData !!!!
// modify pDestObj if set, this object otherwise
ScDPSaveData* pModifyData = pDestObj ? ( pDestObj->pSaveData ) : pSaveData;
@@ -2065,8 +2065,8 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
bool bDataFound = false;
- //! merge multiple occurrences (data field with different functions)
- //! force data field in one dimension
+ //TODO: merge multiple occurrences (data field with different functions)
+ //TODO: force data field in one dimension
vector<long> aPos;
@@ -2100,7 +2100,7 @@ void lcl_FillOldFields( ScPivotFieldVector& rFields,
if ( eFunc == sheet::GeneralFunction_AUTO )
{
- //! test for numeric data
+ //TODO: test for numeric data
eFunc = sheet::GeneralFunction_SUM;
}
@@ -2302,7 +2302,7 @@ bool ScDPObject::FillLabelDataForDimension(
bool bData = ScUnoHelpFunctions::GetBoolProperty(
xDimProp, OUString(SC_UNO_DP_ISDATALAYOUT));
- //! error checking -- is "IsDataLayoutDimension" property required??
+ //TODO: error checking -- is "IsDataLayoutDimension" property required??
sal_Int32 nOrigPos = -1;
OUString aFieldName;
@@ -3201,7 +3201,7 @@ uno::Reference<sdbc::XRowSet> ScDPCollection::DBCaches::createRowSet(
catch ( const sdbc::SQLException& rError )
{
- //! store error message
+ //TODO: store error message
InfoBox aInfoBox( 0, OUString(rError.Message) );
aInfoBox.Execute();
diff --git a/sc/source/core/data/dpoutput.cxx b/sc/source/core/data/dpoutput.cxx
index e903681..0231b68 100644
--- a/sc/source/core/data/dpoutput.cxx
+++ b/sc/source/core/data/dpoutput.cxx
@@ -99,7 +99,7 @@ struct ScDPOutLevelData
void Swap(ScDPOutLevelData& r)
{ ScDPOutLevelData aTemp; aTemp = r; r = *this; *this = aTemp; }
- //! bug (73840) in uno::Sequence - copy and then assign doesn't work!
+ // bug (73840) in uno::Sequence - copy and then assign doesn't work!
};
namespace {
@@ -331,7 +331,7 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
return; // already set
// xLevRes is from the data layout dimension
//! use result sequence from ScDPOutLevelData!
uno::Sequence<sheet::MemberResult> aResult = xLevRes->getResults();
@@ -340,7 +340,7 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
return;
// get names/formats for all data dimensions
//! merge this with the loop to collect ScDPOutLevelData?
OUString aDataNames[SC_DPOUT_MAXLEVELS];
sal_uInt32 nDataFormats[SC_DPOUT_MAXLEVELS];
@@ -389,13 +389,13 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
for (long nPos=0; nPos<nSize; nPos++)
{
// if CONTINUE bit is set, keep previous name
//! keep number format instead!
if ( !(pArray[nPos].Flags & sheet::MemberResultFlags::CONTINUE) )
aName = pArray[nPos].Name;
sal_uInt32 nFormat = 0;
for (long i=0; i<nDataCount; i++)
- if (aName == aDataNames[i]) //! search more efficiently?
+ if (aName == aDataNames[i]) //TODO: search more efficiently?
{
nFormat = nDataFormats[i];
break;
@@ -806,7 +806,7 @@ void ScDPOutput::HeaderCell( SCCOL nCol, SCROW nRow, SCTAB nTab,
ScDPOutputImpl outputimp( pDoc, nTab,
nTabStartCol, nTabStartRow,
nDataStartCol, nDataStartRow, nTabEndCol, nTabEndRow );
//! limit frames to horizontal or vertical?
if (bColHeader)
{
outputimp.OutputBlockFrame( nCol,nMemberStartRow+(SCROW)nLevel, nCol,nDataStartRow-1 );
@@ -873,7 +873,7 @@ void ScDPOutput::CalcSizes()
if (!bSizesValid)
{
// get column size of data from first row
//! allow different sizes (and clear following areas) ???
nRowCount = aData.getLength();
const uno::Sequence<sheet::DataResult>* pRowAry = aData.getConstArray();
@@ -886,7 +886,7 @@ void ScDPOutput::CalcSizes()
// calculate output positions and sizes
- long nPageSize = 0; //! use page fields!
+ long nPageSize = 0; // use page fields!
if ( bDoFilter || nPageFieldCount )
{
nPageSize += nPageFieldCount + 1; // plus one empty row
@@ -977,8 +977,8 @@ void ScDPOutput::Output()
return; // nothing
// clear whole (new) output area
- //! when modifying table, clear old area
- //! include IDF_OBJECTS ???
+ // when modifying table, clear old area !
+ //TODO: include IDF_OBJECTS ???
pDoc->DeleteAreaTab( aStartPos.Col(), aStartPos.Row(), nTabEndCol, nTabEndRow, nTab, IDF_ALL );
if ( bDoFilter )
@@ -1014,7 +1014,7 @@ void ScDPOutput::Output()
if (aDataDescription.isEmpty())
{
//! use default string ("result") ?
}
pDoc->SetString(nTabStartCol, nTabStartRow, nTab, aDataDescription);
@@ -1032,17 +1032,17 @@ void ScDPOutput::Output()
nDataStartCol, nDataStartRow, nTabEndCol, nTabEndRow );
for (nField=0; nField<nColFieldCount; nField++)
{
- SCCOL nHdrCol = nDataStartCol + (SCCOL)nField; //! check for overflow
+ SCCOL nHdrCol = nDataStartCol + (SCCOL)nField; //TODO: check for overflow
FieldCell(nHdrCol, nTabStartRow, nTab, pColFields[nField], true);
- SCROW nRowPos = nMemberStartRow + (SCROW)nField; //! check for overflow
+ SCROW nRowPos = nMemberStartRow + (SCROW)nField; //TODO: check for overflow
const uno::Sequence<sheet::MemberResult> rSequence = pColFields[nField].aResult;
const sheet::MemberResult* pArray = rSequence.getConstArray();
long nThisColCount = rSequence.getLength();
- OSL_ENSURE( nThisColCount == nColCount, "count mismatch" ); //! ???
+ OSL_ENSURE( nThisColCount == nColCount, "count mismatch" ); //TODO: ???
for (long nCol=0; nCol<nThisColCount; nCol++)
{
- SCCOL nColPos = nDataStartCol + (SCCOL)nCol; //! check for overflow
+ SCCOL nColPos = nDataStartCol + (SCCOL)nCol; //TODO: check for overflow
HeaderCell( nColPos, nRowPos, nTab, pArray[nCol], true, nField );
if ( ( pArray[nCol].Flags & sheet::MemberResultFlags::HASMEMBER ) &&
!( pArray[nCol].Flags & sheet::MemberResultFlags::SUBTOTAL ) )
@@ -1050,7 +1050,7 @@ void ScDPOutput::Output()
long nEnd = nCol;
while ( nEnd+1 < nThisColCount && ( pArray[nEnd+1].Flags & sheet::MemberResultFlags::CONTINUE ) )
++nEnd;
- SCCOL nEndColPos = nDataStartCol + (SCCOL)nEnd; //! check for overflow
+ SCCOL nEndColPos = nDataStartCol + (SCCOL)nEnd; //TODO: check for overflow
if ( nField+1 < nColFieldCount )
{
if ( nField == nColFieldCount - 2 )
@@ -1082,18 +1082,18 @@ void ScDPOutput::Output()
vbSetBorder.resize( nTabEndRow - nDataStartRow + 1, false );
for (nField=0; nField<nRowFieldCount; nField++)
{
- SCCOL nHdrCol = nTabStartCol + (SCCOL)nField; //! check for overflow
+ SCCOL nHdrCol = nTabStartCol + (SCCOL)nField; //TODO: check for overflow
SCROW nHdrRow = nDataStartRow - 1;
FieldCell(nHdrCol, nHdrRow, nTab, pRowFields[nField], true);
- SCCOL nColPos = nMemberStartCol + (SCCOL)nField; //! check for overflow
+ SCCOL nColPos = nMemberStartCol + (SCCOL)nField; //TODO: check for overflow
const uno::Sequence<sheet::MemberResult> rSequence = pRowFields[nField].aResult;
const sheet::MemberResult* pArray = rSequence.getConstArray();
long nThisRowCount = rSequence.getLength();
- OSL_ENSURE( nThisRowCount == nRowCount, "count mismatch" ); //! ???
+ OSL_ENSURE( nThisRowCount == nRowCount, "count mismatch" ); //TODO: ???
for (long nRow=0; nRow<nThisRowCount; nRow++)
{
- SCROW nRowPos = nDataStartRow + (SCROW)nRow; //! check for overflow
+ SCROW nRowPos = nDataStartRow + (SCROW)nRow; //TODO: check for overflow
HeaderCell( nColPos, nRowPos, nTab, pArray[nRow], false, nField );
if ( ( pArray[nRow].Flags & sheet::MemberResultFlags::HASMEMBER ) &&
!( pArray[nRow].Flags & sheet::MemberResultFlags::SUBTOTAL ) )
@@ -1103,7 +1103,7 @@ void ScDPOutput::Output()
long nEnd = nRow;
while ( nEnd+1 < nThisRowCount && ( pArray[nEnd+1].Flags & sheet::MemberResultFlags::CONTINUE ) )
++nEnd;
- SCROW nEndRowPos = nDataStartRow + (SCROW)nEnd; //! check for overflow
+ SCROW nEndRowPos = nDataStartRow + (SCROW)nEnd; //TODO: check for overflow
outputimp.AddRow( nRowPos );
if ( vbSetBorder[ nRow ] == false )
{
@@ -1141,13 +1141,13 @@ void ScDPOutput::Output()
for (long nRow=0; nRow<nRowCount; nRow++)
{
- SCROW nRowPos = nDataStartRow + (SCROW)nRow; //! check for overflow
+ SCROW nRowPos = nDataStartRow + (SCROW)nRow; //TODO: check for overflow
const sheet::DataResult* pColAry = pRowAry[nRow].getConstArray();
long nThisColCount = pRowAry[nRow].getLength();
- OSL_ENSURE( nThisColCount == nColCount, "count mismatch" ); //! ???
+ OSL_ENSURE( nThisColCount == nColCount, "count mismatch" ); //TODO: ???
for (long nCol=0; nCol<nThisColCount; nCol++)
{
- SCCOL nColPos = nDataStartCol + (SCCOL)nCol; //! check for overflow
+ SCCOL nColPos = nDataStartCol + (SCCOL)nCol; //TODO: check for overflow
DataCell( nColPos, nRowPos, nTab, pColAry[nCol] );
}
}
@@ -1584,11 +1584,11 @@ void ScDPOutput::GetDataDimensionNames(
if ( xDimProp.is() && xDimName.is() )
{
// Asterisks are added in ScDPSaveData::WriteToSource to create unique names.
//! preserve original name there?
rSourceName = ScDPUtil::getSourceDimensionName(xDimName->getName());
// Generate "given name" the same way as in dptabres.
//! Should use a stored name when available
sheet::GeneralFunction eFunc = (sheet::GeneralFunction)ScUnoHelpFunctions::GetEnumProperty(
xDimProp, OUString(SC_UNO_DP_FUNCTION),
@@ -1649,7 +1649,7 @@ long ScDPOutput::GetHeaderDim( const ScAddress& rPos, sal_uInt16& rOrient )
return pPageFields[nField].nDim;
}
//! single data field (?)
rOrient = sheet::DataPilotFieldOrientation_HIDDEN;
return -1; // invalid
@@ -1682,7 +1682,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
nField = 0;
bMouseTop = true;
}
//! find start of dimension
rPosRect = Rectangle( nDataStartCol, nMemberStartRow + nField,
nTabEndCol, nMemberStartRow + nField -1 );
@@ -1736,7 +1736,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
nCol + 1 >= nTabStartCol && nCol < nTabStartCol + nRowFieldCount ) )
{
long nField = nCol - nTabStartCol;
//! find start of dimension
rPosRect = Rectangle( nTabStartCol + nField, nDataStartRow - 1,
nTabStartCol + nField - 1, nTabEndRow );
@@ -1792,7 +1792,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
nField = 0;
bMouseTop = true;
}
//! find start of dimension
rPosRect = Rectangle( aStartPos.Col(), nPageStartRow + nField,
nTabEndCol, nPageStartRow + nField - 1 );
@@ -331,7 +331,7 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
return; // already set
// xLevRes is from the data layout dimension
- //! use result sequence from ScDPOutLevelData!
+ //TODO: use result sequence from ScDPOutLevelData!
uno::Sequence<sheet::MemberResult> aResult = xLevRes->getResults();
@@ -340,7 +340,7 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
return;
// get names/formats for all data dimensions
- //! merge this with the loop to collect ScDPOutLevelData?
+ //TODO: merge this with the loop to collect ScDPOutLevelData?
OUString aDataNames[SC_DPOUT_MAXLEVELS];
sal_uInt32 nDataFormats[SC_DPOUT_MAXLEVELS];
@@ -389,13 +389,13 @@ void lcl_FillNumberFormats( sal_uInt32*& rFormats, long& rCount,
{
// if CONTINUE bit is set, keep previous name
- //! keep number format instead!
+ //TODO: keep number format instead!
if ( !(pArray[nPos].Flags & sheet::MemberResultFlags::CONTINUE) )
aName = pArray[nPos].Name;
@@ -806,7 +806,7 @@ void ScDPOutput::HeaderCell( SCCOL nCol, SCROW nRow, SCTAB nTab,
nTabStartCol, nTabStartRow,
nDataStartCol, nDataStartRow, nTabEndCol, nTabEndRow );
- //! limit frames to horizontal or vertical?
+ //TODO: limit frames to horizontal or vertical?
if (bColHeader)
{
@@ -873,7 +873,7 @@ void ScDPOutput::CalcSizes()
{
// get column size of data from first row
- //! allow different sizes (and clear following areas) ???
+ //TODO: allow different sizes (and clear following areas) ???
nRowCount = aData.getLength();
const uno::Sequence<sheet::DataResult>* pRowAry = aData.getConstArray();
@@ -1014,7 +1014,7 @@ void ScDPOutput::Output()
if (aDataDescription.isEmpty())
{
- //! use default string ("result") ?
+ //TODO: use default string ("result") ?
}
pDoc->SetString(nTabStartCol, nTabStartRow, nTab, aDataDescription);
@@ -1584,11 +1584,11 @@ void ScDPOutput::GetDataDimensionNames(
{
// Asterisks are added in ScDPSaveData::WriteToSource to create unique names.
- //! preserve original name there?
+ //TODO: preserve original name there?
rSourceName = ScDPUtil::getSourceDimensionName(xDimName->getName());
// Generate "given name" the same way as in dptabres.
@@ -1584,11 +1584,11 @@ void ScDPOutput::GetDataDimensionNames(
rSourceName = ScDPUtil::getSourceDimensionName(xDimName->getName());
// Generate "given name" the same way as in dptabres.
- //! Should use a stored name when available
+ //TODO: Should use a stored name when available
sheet::GeneralFunction eFunc = (sheet::GeneralFunction)ScUnoHelpFunctions::GetEnumProperty(
xDimProp, OUString(SC_UNO_DP_FUNCTION),
@@ -1649,7 +1649,7 @@ long ScDPOutput::GetHeaderDim( const ScAddress& rPos, sal_uInt16& rOrient )
return pPageFields[nField].nDim;
}
- //! single data field (?)
+ //TODO: single data field (?)
rOrient = sheet::DataPilotFieldOrientation_HIDDEN;
return -1; // invalid
@@ -1682,7 +1682,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
bMouseTop = true;
}
- //! find start of dimension
+ //TODO: find start of dimension
rPosRect = Rectangle( nDataStartCol, nMemberStartRow + nField,
nTabEndCol, nMemberStartRow + nField -1 );
@@ -1736,7 +1736,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
{
long nField = nCol - nTabStartCol;
- //! find start of dimension
+ //TODO: find start of dimension
rPosRect = Rectangle( nTabStartCol + nField, nDataStartRow - 1,
nTabStartCol + nField - 1, nTabEndRow );
@@ -1792,7 +1792,7 @@ bool ScDPOutput::GetHeaderDrag( const ScAddress& rPos, bool bMouseLeft, bool bMo
bMouseTop = true;
}
- //! find start of dimension
+ //TODO: find start of dimension
rPosRect = Rectangle( aStartPos.Col(), nPageStartRow + nField,
nTabEndCol, nPageStartRow + nField - 1 );
diff --git a/sc/source/core/data/dptabdat.cxx b/sc/source/core/data/dptabdat.cxx
index 3558c86..073ff59 100644
--- a/sc/source/core/data/dptabdat.cxx
+++ b/sc/source/core/data/dptabdat.cxx
@@ -52,7 +52,7 @@ ScDPTableData::ScDPTableData(ScDocument* pDoc) :
{
nLastDateVal = nLastHier = nLastLevel = nLastRet = -1; // invalid
//! reset before new calculation (in case the base date is changed)
}
ScDPTableData::~ScDPTableData()
@@ -70,7 +70,7 @@ long ScDPTableData::GetDatePart( long nDateVal, long nHierarchy, long nLevel )
if ( nDateVal == nLastDateVal && nHierarchy == nLastHier && nLevel == nLastLevel )
return nLastRet;
- Date aDate( 30,12,1899 ); //! get from source data (and cache here)
+ Date aDate( 30,12,1899 ); //TODO: get from source data (and cache here)
aDate += nDateVal;
long nRet = 0;
@@ -90,7 +90,7 @@ long ScDPTableData::GetDatePart( long nDateVal, long nHierarchy, long nLevel )
case SC_DAPI_HIERARCHY_WEEK:
switch (nLevel)
{
//! use settings for different definitions
case 0: nRet = aDate.GetYear(); break; //!...
case 1: nRet = aDate.GetWeekOfYear(); break;
case 2: nRet = (long)aDate.GetDayOfWeek(); break;
@@ -195,7 +195,7 @@ void ScDPTableData::ProcessRowData(CalcInfo& rInfo, const CalcRowData& rData, bo
if ( ( !rInfo.pColRoot->GetChildDimension() || rInfo.pColRoot->GetChildDimension()->IsValidEntry(rData.aColData) ) &&
( !rInfo.pRowRoot->GetChildDimension() || rInfo.pRowRoot->GetChildDimension()->IsValidEntry(rData.aRowData) ) )
{
//! single process method with ColMembers, RowMembers and data !!!
if (rInfo.pColRoot->GetChildDimension())
{
vector<SCROW> aEmptyData;
@@ -52,7 +52,7 @@ ScDPTableData::ScDPTableData(ScDocument* pDoc) :
{
nLastDateVal = nLastHier = nLastLevel = nLastRet = -1; // invalid
- //! reset before new calculation (in case the base date is changed)
+ //TODO: reset before new calculation (in case the base date is changed)
}
ScDPTableData::~ScDPTableData()
@@ -90,7 +90,7 @@ long ScDPTableData::GetDatePart( long nDateVal, long nHierarchy, long nLevel )
switch (nLevel)
{
- //! use settings for different definitions
+ //TODO: use settings for different definitions
case 0: nRet = aDate.GetYear(); break; //!...
case 1: nRet = aDate.GetWeekOfYear(); break;
@@ -195,7 +195,7 @@ void ScDPTableData::ProcessRowData(CalcInfo& rInfo, const CalcRowData& rData, bo
( !rInfo.pRowRoot->GetChildDimension() || rInfo.pRowRoot->GetChildDimension()->IsValidEntry(rData.aRowData) ) )
{
- //! single process method with ColMembers, RowMembers and data !!!
+ //TODO: single process method with ColMembers, RowMembers and data !!!
if (rInfo.pColRoot->GetChildDimension())
{
diff --git a/sc/source/core/data/dptabres.cxx b/sc/source/core/data/dptabres.cxx
index 7d543c0..00eecec 100644
--- a/sc/source/core/data/dptabres.cxx
+++ b/sc/source/core/data/dptabres.cxx
@@ -515,7 +515,7 @@ void ScDPAggData::Calculate( ScSubTotalFunc eFunc, const ScDPSubTotalState& rSub
fResult = fVal / (double) nCount;
break;
//! use safe mul for fVal * fVal
case SUBTOTAL_FUNC_STD:
if ( nCount >= 2 )
@@ -702,7 +702,7 @@ static ScSubTotalFunc lcl_GetForceFunc( const ScDPLevel* pLevel, long nFuncNo )
ScSubTotalFunc eRet = SUBTOTAL_FUNC_NONE;
if ( pLevel )
{
//! direct access via ScDPLevel
uno::Sequence<sheet::GeneralFunction> aSeq = pLevel->getSubTotals();
long nSequence = aSeq.getLength();
@@ -985,7 +985,7 @@ void ScDPResultMember::FillItemData( ScDPItemData& rData ) const
bool ScDPResultMember::IsNamedItem( SCROW nIndex ) const
{
//! store ScDPMember pointer instead of ScDPMember ???
const ScDPMember* pMemberDesc = GetDPMember();
if (pMemberDesc)
return pMemberDesc->IsNamedItem(nIndex);
@@ -1210,7 +1210,7 @@ long ScDPResultMember::GetSubTotalCount( long* pUserSubStart ) const
return 1; // grand total is always "automatic"
else if ( pParentLevel )
{
//! direct access via ScDPLevel
uno::Sequence<sheet::GeneralFunction> aSeq = pParentLevel->getSubTotals();
long nSequence = aSeq.getLength();
@@ -1862,7 +1862,7 @@ static long lcl_GetSubTotalPos( const ScDPSubTotalState& rSubState )
void ScDPDataMember::UpdateValues( const vector<ScDPValue>& aValues, const ScDPSubTotalState& rSubState )
{
//! find out how many and which subtotals are used
ScDPAggData* pAgg = &aAggregate;
@@ -1929,7 +1929,7 @@ bool ScDPDataMember::HasData( long nMeasure, const ScDPSubTotalState& rSubState
const ScDPAggData* pAgg = GetConstAggData( nMeasure, rSubState );
if (!pAgg)
- return false; //! error?
+ return false; //TODO: error?
return pAgg->HasData();
}
@@ -1947,7 +1947,7 @@ double ScDPDataMember::GetAggregate( long nMeasure, const ScDPSubTotalState& rSu
{
const ScDPAggData* pAgg = GetConstAggData( nMeasure, rSubState );
if (!pAgg)
- return DBL_MAX; //! error?
+ return DBL_MAX; //TODO: error?
return pAgg->GetResult();
}
@@ -1965,7 +1965,7 @@ ScDPAggData* ScDPDataMember::GetAggData( long nMeasure, const ScDPSubTotalState&
nSkip += nSubPos * pResultData->GetMeasureCount();
for ( long nPos=0; nPos<nSkip; nPos++ )
- pAgg = pAgg->GetChild(); //! need to create children here?
+ pAgg = pAgg->GetChild(); //TODO: need to create children here?
return pAgg;
}
@@ -2167,7 +2167,7 @@ void ScDPDataMember::UpdateDataRow(
ScDPAggData* pAggData = GetAggData( nMemberMeasure, aLocalSubState );
if (pAggData)
{
- //! aLocalSubState?
+ //TODO: aLocalSubState?
ScSubTotalFunc eFunc = pResultData->GetMeasureFunction( nMemberMeasure );
sheet::DataPilotFieldReference aReferenceValue = pResultData->GetMeasureRefVal( nMemberMeasure );
sal_Int32 eRefType = aReferenceValue.ReferenceType;
@@ -2199,7 +2199,7 @@ void ScDPDataMember::SortMembers( ScDPResultMember* pRefMember )
{
OSL_ENSURE( pRefMember == pResultMember || !pResultMember, "bla" );
- if ( pRefMember->IsVisible() ) //! here or in ScDPDataDimension ???
+ if ( pRefMember->IsVisible() ) //TODO: here or in ScDPDataDimension ???
{
ScDPDataDimension* pDataChild = GetChildDimension();
ScDPResultDimension* pRefChild = pRefMember->GetChildDimension();
@@ -2212,7 +2212,7 @@ void ScDPDataMember::DoAutoShow( ScDPResultMember* pRefMember )
{
OSL_ENSURE( pRefMember == pResultMember || !pResultMember, "bla" );
- if ( pRefMember->IsVisible() ) //! here or in ScDPDataDimension ???
+ if ( pRefMember->IsVisible() ) //TODO: here or in ScDPDataDimension ???
{
ScDPDataDimension* pDataChild = GetChildDimension();
ScDPResultDimension* pRefChild = pRefMember->GetChildDimension();
@@ -2276,7 +2276,7 @@ void ScDPDataMember::UpdateRunningTotals(
ScDPAggData* pAggData = GetAggData( nMemberMeasure, aLocalSubState );
if (pAggData)
{
- //! aLocalSubState?
+ //TODO: aLocalSubState?
sheet::DataPilotFieldReference aReferenceValue = pResultData->GetMeasureRefVal( nMemberMeasure );
sal_Int32 eRefType = aReferenceValue.ReferenceType;
@@ -2298,7 +2298,7 @@ void ScDPDataMember::UpdateRunningTotals(
OUString aRefFieldName = aReferenceValue.ReferenceField;
- //! aLocalSubState?
+ //TODO: aLocalSubState?
sal_uInt16 nRefOrient = pResultData->GetMeasureRefOrient( nMemberMeasure );
bool bRefDimInCol = ( nRefOrient == sheet::DataPilotFieldOrientation_COLUMN );
bool bRefDimInRow = ( nRefOrient == sheet::DataPilotFieldOrientation_ROW );
@@ -2517,7 +2517,7 @@ void ScDPDataMember::UpdateRunningTotals(
pAggData->SetResult(fThisResult);
pAggData->SetEmpty(false); // always display
}
- //! errors in data?
+ //TODO: errors in data?
}
}
else if (bRelative && !bNoDetailsInRef)
@@ -2657,7 +2657,7 @@ ScDPGroupCompare::ScDPGroupCompare( const ScDPResultData* pData, const ScDPInitS
nDimSource( nDimension )
{
bIsBase = pResultData->IsBaseForGroup( nDimSource );
- nGroupBase = pResultData->GetGroupBase( nDimSource ); //! get together in one call?
+ nGroupBase = pResultData->GetGroupBase( nDimSource ); //TODO: get together in one call?
// if bIncludeAll is set, TestIncluded doesn't need to be called
bIncludeAll = !( bIsBase || nGroupBase >= 0 );
@@ -2669,7 +2669,7 @@ bool ScDPGroupCompare::TestIncluded( const ScDPMember& rMember )
if ( bIsBase )
{
// need to check all previous groups
//! get array of groups (or indexes) before loop?
ScDPItemData aMemberData;
rMember.FillItemData( aMemberData );
@@ -2689,7 +2689,7 @@ bool ScDPGroupCompare::TestIncluded( const ScDPMember& rMember )
// base isn't used in preceding fields
// -> look for other groups using the same base
//! get array of groups (or indexes) before loop?
ScDPItemData aMemberData;
rMember.FillItemData( aMemberData );
const std::vector<ScDPInitState::Member>& rMemStates = rInitState.GetMembers();
@@ -2798,7 +2798,7 @@ void ScDPResultDimension::InitFrom(
// global order is used to initialize aMembers, so it doesn't have to be looked at later
const ScMemberSortOrder& rGlobalOrder = pThisLevel->GetGlobalOrder();
- long nDimSource = pThisDim->GetDimension(); //! check GetSourceDim?
+ long nDimSource = pThisDim->GetDimension(); //TODO: check GetSourceDim?
ScDPGroupCompare aCompare( pResultData, rInitState, nDimSource );
// Now, go through all members and initialize them.
@@ -2835,7 +2835,7 @@ void ScDPResultDimension::LateInitFrom(
if (!pThisDim || !pThisLevel)
return;
- long nDimSource = pThisDim->GetDimension(); //! check GetSourceDim?
+ long nDimSource = pThisDim->GetDimension(); //TODO: check GetSourceDim?
bool bShowEmpty = pThisLevel->getShowEmpty();
@@ -3242,7 +3242,7 @@ ScDPDataMember* ScDPResultDimension::GetRowReferenceMember(
const ScDPResultMember* pRowMember = maMemberArray[GetSortedIndex(nMemberIndex)];
//! use ScDPItemData, as in ScDPDimension::IsValidPage?
while ( pRowMember && pRowMember->GetName() != *pName )
{
++nMemberIndex;
@@ -3331,7 +3331,7 @@ ScDPDataMember* ScDPResultDimension::GetColReferenceMember(
}
// get column (data) members before the reference field
//! pass rRowParent from ScDPDataMember::UpdateRunningTotals instead
if ( pRowMember )
{
@@ -3375,7 +3375,7 @@ ScDPDataMember* ScDPResultDimension::GetColReferenceMember(
pColMember = pReferenceDim->GetMember( pReferenceDim->GetSortedIndex( nMemberIndex ) );
//! use ScDPItemData, as in ScDPDimension::IsValidPage?
while ( pColMember && pColMember->GetName() != *pName )
{
++nMemberIndex;
@@ -3605,7 +3605,7 @@ void ScDPDataDimension::FillDataRow(
}
const ScDPResultMember* pRefMember = pRefDim->GetMember(nMemberPos);
- if ( pRefMember->IsVisible() ) //! here or in ScDPDataMember::FillDataRow ???
+ if ( pRefMember->IsVisible() ) //TODO: here or in ScDPDataMember::FillDataRow ???
{
const ScDPDataMember* pDataMember = maMembers[(sal_uInt16)nMemberPos];
pDataMember->FillDataRow(pRefMember, rFilterCxt, rSequence, nMemberMeasure, bIsSubTotalRow, rSubState);
@@ -3668,7 +3668,7 @@ void ScDPDataDimension::SortMembers( ScDPResultDimension* pRefDim )
for (long i=0; i<nLoopCount; i++)
{
ScDPResultMember* pRefMember = pRefDim->GetMember(i);
- if ( pRefMember->IsVisible() ) //! here or in ScDPDataMember ???
+ if ( pRefMember->IsVisible() ) //TODO: here or in ScDPDataMember ???
{
ScDPDataMember* pDataMember = maMembers[(sal_uInt16)i];
pDataMember->SortMembers( pRefMember );
@@ -3690,7 +3690,7 @@ void ScDPDataDimension::DoAutoShow( ScDPResultDimension* pRefDim )
for (long i=0; i<nLoopCount; i++)
{
ScDPResultMember* pRefMember = pRefDim->GetMember(i);
- if ( pRefMember->IsVisible() ) //! here or in ScDPDataMember ???
+ if ( pRefMember->IsVisible() ) //TODO: here or in ScDPDataMember ???
{
ScDPDataMember* pDataMember = maMembers[i];
pDataMember->DoAutoShow( pRefMember );
@@ -3982,7 +3982,7 @@ void ScDPResultDimension::InitWithMembers(
if (pThisDim && pThisLevel)
{
- long nDimSource = pThisDim->GetDimension(); //! check GetSourceDim?
+ long nDimSource = pThisDim->GetDimension(); //TODO: check GetSourceDim?
// create all members at the first call (preserve order)
ResultMembers* pMembers = pResultData->GetDimResultMembers(nDimSource, pThisDim, pThisLevel);
@@ -515,7 +515,7 @@ void ScDPAggData::Calculate( ScSubTotalFunc eFunc, const ScDPSubTotalState& rSub
fResult = fVal / (double) nCount;
break;
- //! use safe mul for fVal * fVal
+ //TODO: use safe mul for fVal * fVal
case SUBTOTAL_FUNC_STD:
if ( nCount >= 2 )
@@ -702,7 +702,7 @@ static ScSubTotalFunc lcl_GetForceFunc( const ScDPLevel* pLevel, long nFuncNo )
if ( pLevel )
{
- //! direct access via ScDPLevel
+ //TODO: direct access via ScDPLevel
uno::Sequence<sheet::GeneralFunction> aSeq = pLevel->getSubTotals();
long nSequence = aSeq.getLength();
@@ -985,7 +985,7 @@ void ScDPResultMember::FillItemData( ScDPItemData& rData ) const
bool ScDPResultMember::IsNamedItem( SCROW nIndex ) const
{
- //! store ScDPMember pointer instead of ScDPMember ???
+ //TODO: store ScDPMember pointer instead of ScDPMember ???
const ScDPMember* pMemberDesc = GetDPMember();
if (pMemberDesc)
@@ -1210,7 +1210,7 @@ long ScDPResultMember::GetSubTotalCount( long* pUserSubStart ) const
else if ( pParentLevel )
{
- //! direct access via ScDPLevel
+ //TODO: direct access via ScDPLevel
uno::Sequence<sheet::GeneralFunction> aSeq = pParentLevel->getSubTotals();
long nSequence = aSeq.getLength();
@@ -1862,7 +1862,7 @@ static long lcl_GetSubTotalPos( const ScDPSubTotalState& rSubState )
void ScDPDataMember::UpdateValues( const vector<ScDPValue>& aValues, const ScDPSubTotalState& rSubState )
{
- //! find out how many and which subtotals are used
+ //TODO: find out how many and which subtotals are used
ScDPAggData* pAgg = &aAggregate;
@@ -2669,7 +2669,7 @@ bool ScDPGroupCompare::TestIncluded( const ScDPMember& rMember )
{
// need to check all previous groups
- //! get array of groups (or indexes) before loop?
+ //TODO: get array of groups (or indexes) before loop?
ScDPItemData aMemberData;
rMember.FillItemData( aMemberData );
@@ -2689,7 +2689,7 @@ bool ScDPGroupCompare::TestIncluded( const ScDPMember& rMember )
// base isn't used in preceding fields
// -> look for other groups using the same base
- //! get array of groups (or indexes) before loop?
+ //TODO: get array of groups (or indexes) before loop?
ScDPItemData aMemberData;
rMember.FillItemData( aMemberData );
@@ -3242,7 +3242,7 @@ ScDPDataMember* ScDPResultDimension::GetRowReferenceMember(
const ScDPResultMember* pRowMember = maMemberArray[GetSortedIndex(nMemberIndex)];
- //! use ScDPItemData, as in ScDPDimension::IsValidPage?
+ //TODO: use ScDPItemData, as in ScDPDimension::IsValidPage?
while ( pRowMember && pRowMember->GetName() != *pName )
{
@@ -3331,7 +3331,7 @@ ScDPDataMember* ScDPResultDimension::GetColReferenceMember(
}
// get column (data) members before the reference field
- //! pass rRowParent from ScDPDataMember::UpdateRunningTotals instead
+ //TODO: pass rRowParent from ScDPDataMember::UpdateRunningTotals instead
if ( pRowMember )
{
@@ -3375,7 +3375,7 @@ ScDPDataMember* ScDPResultDimension::GetColReferenceMember(
pColMember = pReferenceDim->GetMember( pReferenceDim->GetSortedIndex( nMemberIndex ) );
- //! use ScDPItemData, as in ScDPDimension::IsValidPage?
+ //TODO: use ScDPItemData, as in ScDPDimension::IsValidPage?
while ( pColMember && pColMember->GetName() != *pName )
{
diff --git a/sc/source/core/data/dptabsrc.cxx b/sc/source/core/data/dptabsrc.cxx
index 928e110..f5a57b9 100644
--- a/sc/source/core/data/dptabsrc.cxx
+++ b/sc/source/core/data/dptabsrc.cxx
@@ -83,7 +83,7 @@ SC_SIMPLE_SERVICE_INFO( ScDPMember, "ScDPMember", "com.sun.star.sheet.
// property maps for PropertySetInfo
// DataDescription / NumberFormat are internal
-//! move to a header?
+//TODO: move to a header?
static bool lcl_GetBoolFromAny( const uno::Any& aAny )
{
if ( aAny.getValueTypeClass() == uno::TypeClass_BOOLEAN )
@@ -120,7 +120,7 @@ ScDPSource::~ScDPSource()
if (pDimensions)
pDimensions->release(); // ref-counted
- //! free lists
+ // free lists
delete[] pColResults;
delete[] pRowResults;
@@ -245,7 +245,7 @@ void removeDim( long nRemove, std::vector<long>& rDims )
bool ScDPSource::SubTotalAllowed(long nColumn)
{
//! cache this at ScDPResultData
bool bAllowed = true;
if ( testSubTotal(bAllowed, nColumn, maColDims, this) )
return bAllowed;
@@ -256,7 +256,7 @@ bool ScDPSource::SubTotalAllowed(long nColumn)
void ScDPSource::SetOrientation(long nColumn, sal_uInt16 nNew)
{
//! change to no-op if new orientation is equal to old?
// remove from old list
removeDim(nColumn, maColDims);
@@ -335,7 +335,7 @@ ScDPDimension* ScDPSource::AddDuplicated(long /* nSource */, const OUString& rNe
ScDPDimension* pDim = pDimensions->getByIndex(i);
if (pDim && pDim->getName().equals(rNewName))
{
//! test if pDim is a duplicate of source
return pDim;
}
}
@@ -382,7 +382,7 @@ uno::Sequence< uno::Sequence<sheet::DataResult> > SAL_CALL ScDPSource::getResult
long nRowCount = pRowResRoot->GetSize(pResData->GetRowStartMeasure());
// allocate full sequence
//! leave out empty rows???
uno::Sequence< uno::Sequence<sheet::DataResult> > aSeq( nRowCount );
uno::Sequence<sheet::DataResult>* pRowAry = aSeq.getArray();
@@ -444,13 +444,13 @@ void SAL_CALL ScDPSource::refresh() throw(uno::RuntimeException, std::exception)
void SAL_CALL ScDPSource::addRefreshListener( const uno::Reference<util::XRefreshListener >& )
throw(uno::RuntimeException, std::exception)
{
- OSL_FAIL("not implemented"); //! exception?
+ OSL_FAIL("not implemented"); //TODO: exception?
}
void SAL_CALL ScDPSource::removeRefreshListener( const uno::Reference<util::XRefreshListener >& )
throw(uno::RuntimeException, std::exception)
{
- OSL_FAIL("not implemented"); //! exception?
+ OSL_FAIL("not implemented"); //TODO: exception?
}
Sequence< Sequence<Any> > SAL_CALL ScDPSource::getDrillDownData(const Sequence<sheet::DataPilotFieldFilter>& aFilters)
@@ -604,7 +604,7 @@ static long lcl_CountMinMembers(const vector<ScDPDimension*>& ppDim, const vecto
if ( nThisCount == 0 )
{
nTotal = 1; // empty level -> start counting from here
//! start with visible elements in this level?
}
else
{
@@ -647,10 +647,10 @@ void ScDPSource::FillCalcInfo(bool bIsRow, ScDPTableData::CalcInfo& rInfo, bool
ScDPLevels* pLevels = pDim->GetHierarchiesObject()->getByIndex(nHierarchy)->GetLevelsObject();
long nCount = pLevels->getCount();
- //! Test
+ //TODO: Test
if (pDim->getIsDataLayoutDimension() && maDataDims.size() < 2)
nCount = 0;
- //! Test
+ //TODO: Test
for (long j = 0; j < nCount; ++j)
{
@@ -819,7 +819,7 @@ void ScDPSource::CreateRes_Impl()
sheet::GeneralFunction eUser = (sheet::GeneralFunction)pDim->getFunction();
if (eUser == sheet::GeneralFunction_AUTO)
{
//! test for numeric data
eUser = sheet::GeneralFunction_SUM;
}
@@ -851,14 +851,14 @@ void ScDPSource::CreateRes_Impl()
aDataNames.push_back(pDim->getName());
//! modify user visible strings as in ScDPResultData::GetMeasureString instead!
aDataNames.back() = ScDPUtil::getSourceDimensionName(aDataNames.back());
//! if the name is overridden by user, a flag must be set
//! so the user defined name replaces the function string and field name.
//! the complete name (function and field) must be stored at the dimension
long nSource = pDim->GetSourceDim();
if (nSource >= 0)
@@ -1159,7 +1159,7 @@ void SAL_CALL ScDPSource::setPropertyValue( const OUString& aPropertyName, const
else
{
OSL_FAIL("unknown property");
- //! THROW( UnknownPropertyException() );
+ //TODO: THROW( UnknownPropertyException() );
}
}
@@ -1192,7 +1192,7 @@ uno::Any SAL_CALL ScDPSource::getPropertyValue( const OUString& aPropertyName )
else
{
OSL_FAIL("unknown property");
- //! THROW( UnknownPropertyException() );
+ //TODO: THROW( UnknownPropertyException() );
}
return aRet;
}
@@ -1213,7 +1213,7 @@ ScDPDimensions::ScDPDimensions( ScDPSource* pSrc ) :
pSource( pSrc ),
ppDims( NULL )
{
- //! hold pSource
+ //TODO: hold pSource
// include data layout dimension and duplicated dimensions
nDimCount = pSource->GetData()->GetColumnCount() + 1 + pSource->GetDupCount();
@@ -1221,7 +1221,7 @@ ScDPDimensions::ScDPDimensions( ScDPSource* pSrc ) :
ScDPDimensions::~ScDPDimensions()
{
- //! release pSource
+ //TODO: release pSource
if (ppDims)
{
@@ -1333,7 +1333,7 @@ ScDPDimension* ScDPDimensions::getByIndex(long nIndex) const
return ppDims[nIndex];
}
- return NULL; //! exception?
+ return NULL; //TODO: exception?
}
ScDPDimension::ScDPDimension( ScDPSource* pSrc, long nD ) :
@@ -1349,12 +1349,12 @@ ScDPDimension::ScDPDimension( ScDPSource* pSrc, long nD ) :
pSelectedData( NULL ),
mbHasHiddenMember(false)
{
- //! hold pSource
+ //TODO: hold pSource
}
ScDPDimension::~ScDPDimension()
{
- //! release pSource
+ //TODO: release pSource
if ( pHierarchies )
pHierarchies->release(); // ref-counted
@@ -1436,13 +1436,13 @@ ScDPDimension* ScDPDimension::CreateCloneObject()
{
OSL_ENSURE( nSourceDim < 0, "recursive duplicate - not implemented" );
//! set new name here, or temporary name ???
OUString aNewName = aName;
ScDPDimension* pNew = pSource->AddDuplicated( nDim, aNewName );
- pNew->aName = aNewName; //! here or in source?
- pNew->nSourceDim = nDim; //! recursive?
+ pNew->aName = aNewName; //TODO: here or in source?
+ pNew->nSourceDim = nDim; //TODO: recursive?
return pNew;
}
@@ -1469,7 +1469,7 @@ const ScDPItemData& ScDPDimension::GetSelectedData()
{
ScDPMembers* pMembers = pLevels->getByIndex(nLevel)->GetMembersObject();
//! merge with ScDPMembers::getByName
long nCount = pMembers->getCount();
for (long i=0; i<nCount && !pSelectedData; i++)
{
@@ -1596,7 +1596,7 @@ void SAL_CALL ScDPDimension::setPropertyValue( const OUString& aPropertyName, co
else
{
OSL_FAIL("unknown property");
- //! THROW( UnknownPropertyException() );
+ //TODO: THROW( UnknownPropertyException() );
}
}
@@ -1687,7 +1687,7 @@ uno::Any SAL_CALL ScDPDimension::getPropertyValue( const OUString& aPropertyName
else
{
OSL_FAIL("unknown property");
- //! THROW( UnknownPropertyException() );
+ //TODO: THROW( UnknownPropertyException() );
}
return aRet;
}
@@ -1699,7 +1699,7 @@ ScDPHierarchies::ScDPHierarchies( ScDPSource* pSrc, long nD ) :
nDim( nD ),
ppHiers( NULL )
{
- //! hold pSource
+ //TODO: hold pSource
// date columns have 3 hierarchies (flat/quarter/week), other columns only one
@@ -1709,7 +1709,7 @@ ScDPHierarchies::ScDPHierarchies( ScDPSource* pSrc, long nD ) :
ScDPHierarchies::~ScDPHierarchies()
{
- //! release pSource
+ //TODO: release pSource
if (ppHiers)
{
@@ -1797,7 +1797,7 @@ ScDPHierarchy* ScDPHierarchies::getByIndex(long nIndex) const
return ppHiers[nIndex];
}
- return NULL; //! exception?
+ return NULL; //TODO: exception?
}
ScDPHierarchy::ScDPHierarchy( ScDPSource* pSrc, long nD, long nH ) :
@@ -1806,12 +1806,12 @@ ScDPHierarchy::ScDPHierarchy( ScDPSource* pSrc, long nD, long nH ) :
nHier( nH ),
pLevels( NULL )
{
- //! hold pSource
+ //TODO: hold pSource
}
ScDPHierarchy::~ScDPHierarchy()
{
- //! release pSource
+ //TODO: release pSource
if (pLevels)
pLevels->release(); // ref-counted
@@ -1835,18 +1835,18 @@ uno::Reference<container::XNameAccess> SAL_CALL ScDPHierarchy::getLevels()
OUString SAL_CALL ScDPHierarchy::getName() throw(uno::RuntimeException, std::exception)
{
- OUString aRet; //! globstr-ID !!!!
+ OUString aRet; //TODO: globstr-ID !!!!
switch (nHier)
{
case SC_DAPI_HIERARCHY_FLAT:
aRet = "flat";
- break; //! name ???????
+ break; //TODO: name ???????
case SC_DAPI_HIERARCHY_QUARTER:
aRet = "Quarter";
- break; //! name ???????
+ break; //TODO: name ???????
case SC_DAPI_HIERARCHY_WEEK:
aRet = "Week";
- break; //! name ???????
+ break; //TODO: name ???????
default:
OSL_FAIL( "ScDPHierarchy::getName: unexpected hierarchy" );
break;
@@ -1856,7 +1856,7 @@ OUString SAL_CALL ScDPHierarchy::getName() throw(uno::RuntimeException, std::exc
void SAL_CALL ScDPHierarchy::setName( const OUString& /* rNewName */ ) throw(uno::RuntimeException, std::exception)
{
- OSL_FAIL("not implemented"); //! exception?
+ OSL_FAIL("not implemented"); //TODO: exception?
}
ScDPLevels::ScDPLevels( ScDPSource* pSrc, long nD, long nH ) :
@@ -1865,7 +1865,7 @@ ScDPLevels::ScDPLevels( ScDPSource* pSrc, long nD, long nH ) :
nHier( nH ),
ppLevs( NULL )
{
- //! hold pSource
+ //TODO: hold pSource
// text columns have only one level
@@ -1888,7 +1888,7 @@ ScDPLevels::ScDPLevels( ScDPSource* pSrc, long nD, long nH ) :
ScDPLevels::~ScDPLevels()
{
- //! release pSource
+ //TODO: release pSource
if (ppLevs)
{
@@ -1973,7 +1973,7 @@ ScDPLevel* ScDPLevels::getByIndex(long nIndex) const
return ppLevs[nIndex];
}
- return NULL; //! exception?
+ return NULL; //TODO: exception?
}
class ScDPGlobalMembersOrder
@@ -2017,13 +2017,13 @@ ScDPLevel::ScDPLevel( ScDPSource* pSrc, long nD, long nH, long nL ) :
bShowEmpty( false ),
bEnableLayout( false )
{
- //! hold pSource
+ //TODO: hold pSource
// aSubTotals is empty
}
ScDPLevel::~ScDPLevel()
{
- //! release pSource
+ //TODO: release pSource
if ( pMembers )
pMembers->release(); // ref-counted
@@ -2047,7 +2047,7 @@ void ScDPLevel::EvaluateSortOrder()
}
}
//! error if not found?
}
break;
case sheet::DataPilotFieldSortMode::MANUAL:
@@ -2082,7 +2082,7 @@ void ScDPLevel::EvaluateSortOrder()
}
}
//! error if not found?
}
}
@@ -2112,7 +2112,7 @@ uno::Sequence<sheet::MemberResult> SAL_CALL ScDPLevel::getResults() throw(uno::R
if (pRes)
return *pRes;
- return uno::Sequence<sheet::MemberResult>(0); //! Error?
+ return uno::Sequence<sheet::MemberResult>(0); //TODO: Error?
}
OUString SAL_CALL ScDPLevel::getName() throw(uno::RuntimeException, std::exception)
@@ -2120,7 +2120,7 @@ OUString SAL_CALL ScDPLevel::getName() throw(uno::RuntimeException, std::excepti
long nSrcDim = pSource->GetSourceDim( nDim );
if ( pSource->IsDateDimension( nSrcDim ) )
{
- OUString aRet; //! globstr-ID !!!!
+ OUString aRet; //TODO: globstr-ID !!!!
if ( nHier == SC_DAPI_HIERARCHY_QUARTER )
{
@@ -2174,12 +2174,12 @@ OUString SAL_CALL ScDPLevel::getName() throw(uno::RuntimeException, std::excepti
void SAL_CALL ScDPLevel::setName( const OUString& /* rNewName */ ) throw(uno::RuntimeException, std::exception)
{
- OSL_FAIL("not implemented"); //! exception?
+ OSL_FAIL("not implemented"); //TODO: exception?
}
uno::Sequence<sheet::GeneralFunction> ScDPLevel::getSubTotals() const
{
//! separate functions for settings and evaluation?
long nSrcDim = pSource->GetSourceDim( nDim );
if ( !pSource->SubTotalAllowed( nSrcDim ) )
@@ -2197,7 +2197,7 @@ uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPLevel::getPropertySetInfo()
static const SfxItemPropertyMapEntry aDPLevelMap_Impl[] =
{
//! change type of AutoShow/Layout/Sorting to API struct when available
{ OUString(SC_UNO_DP_AUTOSHOW), 0, cppu::UnoType<sheet::DataPilotFieldAutoShowInfo>::get(), 0, 0 },
{ OUString(SC_UNO_DP_LAYOUT), 0, cppu::UnoType<sheet::DataPilotFieldLayoutInfo>::get(), 0, 0 },
{ OUString(SC_UNO_DP_SHOWEMPTY), 0, getBooleanCppuType(), 0, 0 },
@@ -2240,7 +2240,7 @@ uno::Any SAL_CALL ScDPLevel::getPropertyValue( const OUString& aPropertyName )
lcl_SetBoolInAny(aRet, bShowEmpty);
else if ( aPropertyName == SC_UNO_DP_SUBTOTAL )
{
- uno::Sequence<sheet::GeneralFunction> aSeq = getSubTotals(); //! avoid extra copy?
+ uno::Sequence<sheet::GeneralFunction> aSeq = getSubTotals(); //TODO: avoid extra copy?
aRet <<= aSeq;
}
else if ( aPropertyName == SC_UNO_DP_SORTING )
@@ -2278,7 +2278,7 @@ ScDPMembers::ScDPMembers( ScDPSource* pSrc, long nD, long nH, long nL ) :
nHier( nH ),
nLev( nL )
{
- //! hold pSource
+ //TODO: hold pSource
long nSrcDim = pSource->GetSourceDim( nDim );
if ( pSource->IsDataLayoutDimension(nSrcDim) )
@@ -2333,7 +2333,7 @@ ScDPMembers::ScDPMembers( ScDPSource* pSrc, long nD, long nH, long nL ) :
{
switch (nLev)
{
- case SC_DAPI_LEVEL_YEAR: nMbrCount = 1; break; //! get years from source
+ case SC_DAPI_LEVEL_YEAR: nMbrCount = 1; break; //TODO: get years from source
case SC_DAPI_LEVEL_WEEK: nMbrCount = 53; break;
case SC_DAPI_LEVEL_WEEKDAY: nMbrCount = 7; break;
default:
@@ -2472,7 +2472,7 @@ ScDPMember* ScDPMembers::getByIndex(long nIndex) const
if ( nLev == SC_DAPI_LEVEL_YEAR ) // YEAR is in both hierarchies
{
//! cache year range here!
double fFirstVal = pSource->GetData()->GetMemberByIndex( nSrcDim, 0 )->GetValue();
long nFirstYear = pSource->GetData()->GetDatePart(
@@ -2535,7 +2535,7 @@ ScDPMember* ScDPMembers::getByIndex(long nIndex) const
return maMembers[nIndex].get();
}
- return NULL; //! exception?
+ return NULL; //TODO: exception?
}
ScDPMember::ScDPMember(
@@ -2550,12 +2550,12 @@ ScDPMember::ScDPMember(
bVisible( true ),
bShowDet( true )
{
- //! hold pSource
+ //TODO: hold pSource
}
ScDPMember::~ScDPMember()
{
- //! release pSource
+ //TODO: release pSource
}
bool ScDPMember::IsNamedItem(SCROW nIndex) const
@@ -2605,7 +2605,7 @@ sal_Int32 ScDPMember::Compare( const ScDPMember& rOther ) const
void ScDPMember::FillItemData( ScDPItemData& rData ) const
{
//! handle date hierarchy...
const ScDPItemData* pData = GetItemData();
rData = (pData ? *pData : ScDPItemData());
@@ -2631,7 +2631,7 @@ OUString SAL_CALL ScDPMember::getName() throw(uno::RuntimeException, std::except
void SAL_CALL ScDPMember::setName( const OUString& /* rNewName */ ) throw(uno::RuntimeException, std::exception)
{
- OSL_FAIL("not implemented"); //! exception?
+ OSL_FAIL("not implemented"); //TODO: exception?
}
// XPropertySet
@@ -245,7 +245,7 @@ void removeDim( long nRemove, std::vector<long>& rDims )
bool ScDPSource::SubTotalAllowed(long nColumn)
{
- //! cache this at ScDPResultData
+ //TODO: cache this at ScDPResultData
bool bAllowed = true;
if ( testSubTotal(bAllowed, nColumn, maColDims, this) )
@@ -256,7 +256,7 @@ bool ScDPSource::SubTotalAllowed(long nColumn)
void ScDPSource::SetOrientation(long nColumn, sal_uInt16 nNew)
{
- //! change to no-op if new orientation is equal to old?
+ //TODO: change to no-op if new orientation is equal to old?
// remove from old list
removeDim(nColumn, maColDims);
@@ -335,7 +335,7 @@ ScDPDimension* ScDPSource::AddDuplicated(long /* nSource */, const OUString& rNe
if (pDim && pDim->getName().equals(rNewName))
{
- //! test if pDim is a duplicate of source
+ //TODO: test if pDim is a duplicate of source
return pDim;
}
@@ -382,7 +382,7 @@ uno::Sequence< uno::Sequence<sheet::DataResult> > SAL_CALL ScDPSource::getResult
long nRowCount = pRowResRoot->GetSize(pResData->GetRowStartMeasure());
// allocate full sequence
- //! leave out empty rows???
+ //TODO: leave out empty rows???
uno::Sequence< uno::Sequence<sheet::DataResult> > aSeq( nRowCount );
uno::Sequence<sheet::DataResult>* pRowAry = aSeq.getArray();
@@ -604,7 +604,7 @@ static long lcl_CountMinMembers(const vector<ScDPDimension*>& ppDim, const vecto
{
nTotal = 1; // empty level -> start counting from here
- //! start with visible elements in this level?
+ //TODO: start with visible elements in this level?
}
else
@@ -819,7 +819,7 @@ void ScDPSource::CreateRes_Impl()
if (eUser == sheet::GeneralFunction_AUTO)
{
- //! test for numeric data
+ //TODO: test for numeric data
eUser = sheet::GeneralFunction_SUM;
}
@@ -851,14 +851,14 @@ void ScDPSource::CreateRes_Impl()
aDataNames.push_back(pDim->getName());
- //! modify user visible strings as in ScDPResultData::GetMeasureString instead!
+ //TODO: modify user visible strings as in ScDPResultData::GetMeasureString instead!
aDataNames.back() = ScDPUtil::getSourceDimensionName(aDataNames.back());
@@ -851,14 +851,14 @@ void ScDPSource::CreateRes_Impl()
aDataNames.back() = ScDPUtil::getSourceDimensionName(aDataNames.back());
- //! if the name is overridden by user, a flag must be set
- //! so the user defined name replaces the function string and field name.
+ //TODO: if the name is overridden by user, a flag must be set
+ //TODO: so the user defined name replaces the function string and field name.
- //! the complete name (function and field) must be stored at the dimension
+ //TODO: the complete name (function and field) must be stored at the dimension
long nSource = pDim->GetSourceDim();
if (nSource >= 0)
@@ -1436,13 +1436,13 @@ ScDPDimension* ScDPDimension::CreateCloneObject()
{
OSL_ENSURE( nSourceDim < 0, "recursive duplicate - not implemented" );
- //! set new name here, or temporary name ???
+ //TODO: set new name here, or temporary name ???
OUString aNewName = aName;
ScDPDimension* pNew = pSource->AddDuplicated( nDim, aNewName );
@@ -1469,7 +1469,7 @@ const ScDPItemData& ScDPDimension::GetSelectedData()
{
ScDPMembers* pMembers = pLevels->getByIndex(nLevel)->GetMembersObject();
- //! merge with ScDPMembers::getByName
+ //TODO: merge with ScDPMembers::getByName
long nCount = pMembers->getCount();
for (long i=0; i<nCount && !pSelectedData; i++)
@@ -2047,7 +2047,7 @@ void ScDPLevel::EvaluateSortOrder()
}
}
- //! error if not found?
+ //TODO: error if not found?
}
break;
@@ -2082,7 +2082,7 @@ void ScDPLevel::EvaluateSortOrder()
}
}
- //! error if not found?
+ //TODO: error if not found?
}
}
@@ -2174,12 +2174,12 @@ OUString SAL_CALL ScDPLevel::getName() throw(uno::RuntimeException, std::excepti
uno::Sequence<sheet::GeneralFunction> ScDPLevel::getSubTotals() const
{
- //! separate functions for settings and evaluation?
+ //TODO: separate functions for settings and evaluation?
long nSrcDim = pSource->GetSourceDim( nDim );
if ( !pSource->SubTotalAllowed( nSrcDim ) )
@@ -2197,7 +2197,7 @@ uno::Reference<beans::XPropertySetInfo> SAL_CALL ScDPLevel::getPropertySetInfo()
static const SfxItemPropertyMapEntry aDPLevelMap_Impl[] =
{
- //! change type of AutoShow/Layout/Sorting to API struct when available
+ //TODO: change type of AutoShow/Layout/Sorting to API struct when available
{ OUString(SC_UNO_DP_AUTOSHOW), 0, cppu::UnoType<sheet::DataPilotFieldAutoShowInfo>::get(), 0, 0 },
{ OUString(SC_UNO_DP_LAYOUT), 0, cppu::UnoType<sheet::DataPilotFieldLayoutInfo>::get(), 0, 0 },
@@ -2472,7 +2472,7 @@ ScDPMember* ScDPMembers::getByIndex(long nIndex) const
if ( nLev == SC_DAPI_LEVEL_YEAR ) // YEAR is in both hierarchies
{
- //! cache year range here!
+ //TODO: cache year range here!
double fFirstVal = pSource->GetData()->GetMemberByIndex( nSrcDim, 0 )->GetValue();
long nFirstYear = pSource->GetData()->GetDatePart(
@@ -2605,7 +2605,7 @@ sal_Int32 ScDPMember::Compare( const ScDPMember& rOther ) const
void ScDPMember::FillItemData( ScDPItemData& rData ) const
{
- //! handle date hierarchy...
+ //TODO: handle date hierarchy...
const ScDPItemData* pData = GetItemData();
rData = (pData ? *pData : ScDPItemData());
diff --git a/sc/source/core/data/fillinfo.cxx b/sc/source/core/data/fillinfo.cxx
index 0328954..a0779f5 100644
--- a/sc/source/core/data/fillinfo.cxx
+++ b/sc/source/core/data/fillinfo.cxx
@@ -282,7 +282,7 @@ void ScDocument::FillInfo(
if (!nHeight)
nHeight = 1;
- pThisRowInfo->nRowNo = nY; //! Fall < 0 ?
+ pThisRowInfo->nRowNo = nY; //TODO: case < 0 ?
pThisRowInfo->nHeight = nHeight;
pThisRowInfo->bEmptyBack = true;
pThisRowInfo->bEmptyText = true;
@@ -321,7 +321,7 @@ void ScDocument::FillInfo(
if ( bAnyItem && HasAttrib( 0,nRow1,nTab, MAXCOL,nRow2+1,nTab,
HASATTR_ROTATE | HASATTR_CONDITIONAL ) )
{
//! Conditionals auch bei HASATTR_ROTATE abfragen ????
OSL_ENSURE( nArrCount>2, "nArrCount too small" );
FindMaxRotCol( nTab, &pRowInfo[1], nArrCount-1, nCol1, nCol2 );
@@ -372,7 +372,7 @@ void ScDocument::FillInfo(
pInfo->bHideGrid = false; // view-intern
pInfo->bEditEngine = false; // view-intern
- pInfo->pBackground = NULL; //! weglassen?
+ pInfo->pBackground = NULL; //TODO: omit?
pInfo->pPatternAttr = NULL;
pInfo->pConditionSet= NULL;
@@ -422,7 +422,7 @@ void ScDocument::FillInfo(
if (!nThisWidth)
nThisWidth = 1;
- pRowInfo[0].pCellInfo[nArrCol].nWidth = nThisWidth; //! dies sollte reichen
+ pRowInfo[0].pCellInfo[nArrCol].nWidth = nThisWidth; //TODO: this should be enough
ScColumn* pThisCol = &maTabs[nTab]->aCol[nX]; // Spalten-Daten
@@ -555,7 +555,7 @@ void ScDocument::FillInfo(
pStlPool->Find( aData.aStyleName, SFX_STYLE_FAMILY_PARA );
if ( pStyleSheet )
{
- //! Style-Sets cachen !!!
+ //TODO: cache Style-Sets !!!
pInfo->pConditionSet = &pStyleSheet->GetItemSet();
bAnyCondition = true;
@@ -661,7 +661,7 @@ void ScDocument::FillInfo(
RowInfo* pThisRowInfo = &pRowInfo[nArrRow];
CellInfo* pInfo = &pThisRowInfo->pCellInfo[nArrCol];
- pInfo->nWidth = nThisWidth; //! oder nur 0 abfragen ??
+ pInfo->nWidth = nThisWidth; //TODO: or check only 0 ??
}
}
}
@@ -321,7 +321,7 @@ void ScDocument::FillInfo(
HASATTR_ROTATE | HASATTR_CONDITIONAL ) )
{
- //! Conditionals auch bei HASATTR_ROTATE abfragen ????
+ //TODO: check Conditionals also for HASATTR_ROTATE ????
OSL_ENSURE( nArrCount>2, "nArrCount too small" );
FindMaxRotCol( nTab, &pRowInfo[1], nArrCount-1, nCol1, nCol2 );